@@ -10,7 +10,15 @@
 /* define this to enable japanese ID3 tags */
 #undef ENABLE_JAPANESE_TAGS
 
+#undef ENABLE_RUSSIAN_TAGS
+
 #undef HAVE_LIBMIKMOD
 
 #undef HAVE_LIBPNG
 
+#undef HAVE_VIDEO4LINUX
+
+#undef HAVE_OSFMME
+
+#undef HAVE_XF86_KEYSYMS
+
