@@ -10,8 +10,8 @@
  */
 
 
-#ifndef _H
-#define _H
+#ifndef DNDUTIL_H
+#define DNDUTIL_H
 
 
 GList *uri_get_list(gchar *data);
