@@ -132,10 +132,12 @@ static const gchar *info_line_value(gchar *text)
 	gchar *ptr, *ptr2;
 
 	ptr = text;
-	while (*ptr != '=' && *ptr != '\0') ptr++;
+	while (*ptr != '=' && *ptr != ':' && *ptr != '\0') ptr++;
 	if (*ptr == '\0') return NULL;
 	ptr++;
 
+	while (*ptr == ' ') ptr++;
+	
 	/* remove new line char */
 	ptr2 = ptr;
 	while (*ptr2 != '\0')
@@ -150,7 +152,10 @@ static const gchar *info_line_value(gchar *text)
 static gint info_line_key_test(gchar *text, const gchar *key)
 {
 	if (!text || !key) return FALSE;
-	return (strncmp(text, key, strlen(key)) == 0);
+
+	while (*text == ' ' || *text == 9) text++;
+
+	return (strncasecmp(text, key, strlen(key)) == 0);
 }
 
 static gchar *info_line_key(gchar *text)
@@ -171,6 +176,62 @@ static gchar *info_line_key(gchar *text)
 	return ret;
 }
 
+static gint info_time_string_to_val(const gchar *text)
+{
+	const gchar *ptr;
+	gint n;
+	gint value = 0;
+
+	ptr = text;
+	while (*ptr != '\0') ptr++;
+
+	while (ptr > text)
+		{
+		gint mp;
+		gchar *tmp;
+
+		switch (*ptr)
+			{
+			case 's':
+				mp = 1;
+				break;
+			case 'm':
+				mp = 60;
+				break;
+			case 'h':
+				mp = 3600;
+				break;
+			default:
+				ptr--;
+				continue;
+				break;
+			}
+		ptr--;
+		n = 1;
+		while (ptr > text && *ptr != ':')
+			{
+			n++;
+			ptr--;
+			}
+
+		if (*ptr == ':')
+			{
+			tmp = g_strndup(ptr + 1, n - 1);
+			}
+		else
+			{
+			tmp = g_strndup(ptr, n);
+			}
+
+		value += mp * (gint)strtol(tmp, NULL, 10);
+		g_free(tmp);
+
+		if (ptr > text) ptr--;
+		}
+
+	return value;
+}
+
 OGGInfo *ogg123_info_get(const gchar *path)
 {
 	OGGInfo *info = NULL;
@@ -190,60 +251,72 @@ OGGInfo *ogg123_info_get(const gchar *path)
 	if (!f) return NULL;
 
 	info = g_new0(OGGInfo, 1);
+	info->pass_integrity = TRUE;
+	info->bitrate_lower = -1;
+	info->bitrate_upper = -1;
+	info->vendor = NULL;
 
 	while (fgets(buf, sizeof(buf), f) != NULL)
 		{
 		const gchar *value;
 		value = info_line_value(buf);
 
-		if (info_line_key_test(buf, "filename"))
+		if (debug_mode) printf("value is [%s]\n", value);
+
+		if (info_line_key_test(buf, "Warning") || info_line_key_test(buf, "Error"))
 			{
-			info->pass_integrity = TRUE;
+			info->pass_integrity = FALSE;
 			}
-		else if (info_line_key_test(buf, "length"))
+		if (info_line_key_test(buf, "Vendor"))
 			{
-			info->length = (gint)strtol(value, NULL, 10);
+			if (!info->vendor) info->vendor = g_strdup(value);
 			}
-		else if (info_line_key_test(buf, "header_integrity") ||
-			 info_line_key_test(buf, "stream_integrity"))
+		else if (!value)
 			{
-			info->pass_integrity = info->pass_integrity & (strncmp(value, "pass", 4) == 0);
+			continue;
 			}
-		else if (info_line_key_test(buf, "bitrate_nominal"))
+		else if (info_line_key_test(buf, "Playback length"))
 			{
-			info->bitrate_nominal = (gint)strtol(value, NULL, 10);
+			info->length = info_time_string_to_val(value);
 			}
-		else if (info_line_key_test(buf, "bitrate_average"))
+		else if (info_line_key_test(buf, "Nominal bitrate"))
 			{
-			info->bitrate_average = (gint)strtol(value, NULL, 10);
+			info->bitrate_nominal = (gint)(strtol(value, NULL, 10) * 1000.0);
 			}
-		else if (info_line_key_test(buf, "bitrate_upper"))
+		else if (info_line_key_test(buf, "Average bitrate"))
 			{
-			if (strncmp(value, "none", 4) == 0)
-				info->bitrate_upper = 0;
-			else
-				info->bitrate_upper = (gint)strtol(value, NULL, 10);
+			info->bitrate_average = (gint)(strtol(value, NULL, 10) * 1000.0);
 			}
-		else if (info_line_key_test(buf, "bitrate_lower"))
+		else if (info_line_key_test(buf, "Upper bitrate"))
 			{
-			if (strncmp(value, "none", 4) == 0)
-				info->bitrate_lower = 0;
-			else
-				info->bitrate_lower = (gint)strtol(value, NULL, 10);
+			info->bitrate_upper = (gint)(strtol(value, NULL, 10) * 1000.0);
 			}
-		else if (info_line_key_test(buf, "channels"))
+		else if (info_line_key_test(buf, "Lower bitrate"))
+			{
+			info->bitrate_lower = (gint)(strtol(value, NULL, 10) * 1000.0);
+			}
+		else if (info_line_key_test(buf, "Channels"))
 			{
 			info->channels = (gint)strtol(value, NULL, 10);
 			}
 		}
 
 	fclose(f);	/* also closes child_pipe[0] */
+	waitpid(child_pid, NULL, 0);	/* eat zombie */
 
 	info->bytes = filesize(path);
 
 	return info;
 }
 
+void ogg123_info_free(OGGInfo *info)
+{
+	if (!info) return;
+
+	g_free(info->vendor);
+	g_free(info);
+}
+
 /*
  * List is ordered key, value, key, value ...
  * use path_list_free() to free the returned list
@@ -289,6 +362,7 @@ GList *ogg123_comment_get(const gchar *path)
 		}
 
 	fclose(f);	/* also closes child_pipe[0] */
+	waitpid(child_pid, NULL, 0);	/* eat zombie */
 
 	return g_list_reverse(list);
 }
@@ -395,6 +469,7 @@ gint ogg123_comment_set(const gchar *path, GList *comments)
 				}
 			}
 		fclose(f);
+		waitpid(child_pid, NULL, 0);
 		}
 
 	if (errlist)
@@ -875,6 +950,7 @@ static gint ogg123_data_set(SongData *sd, gint read_info)
 		{
 		OGGInfo *info;
 		GList *comments;
+		const gchar *track_text;
 
 		sd->info_loaded = TRUE;
 
@@ -882,12 +958,12 @@ static gint ogg123_data_set(SongData *sd, gint read_info)
 		if (info)
 			{
 			sd->length = info->length;
-			sd->bit_rate = info->bitrate_average / 1000;
+			sd->bit_rate = info->bitrate_nominal / 1000;
 			sd->channels = info->channels;
 			sd->bit_depth = 16;	/* these two correct ? */
 			sd->khz_rate = 44;
 			if (!info->pass_integrity) sd->flags |= SONG_FLAG_PLAY_FAIL;
-			g_free(info);
+			ogg123_info_free(info);
 			}
 
 		comments = ogg123_comment_get(sd->path);
@@ -900,10 +976,28 @@ static gint ogg123_data_set(SongData *sd, gint read_info)
 		sd->album = g_strdup(ogg123_comment_value(comments, "ALBUM"));
 		g_free(sd->genre);
 		sd->genre = g_strdup(ogg123_comment_value(comments, "GENRE"));
+
 		g_free(sd->comment);
-		sd->comment = g_strdup(ogg123_comment_value(comments, "COMMENT"));
+		sd->comment = g_strdup(ogg123_comment_value(comments, "DESCRIPTION"));
+		if (!sd->comment)
+			{
+			/* support old COMMENT created with older GQmpegs */
+			sd->comment = g_strdup(ogg123_comment_value(comments, "COMMENT"));
+			}
+
 		g_free(sd->year);
-		sd->year = g_strdup(ogg123_comment_value(comments, "YEAR"));
+		sd->year = g_strdup(ogg123_comment_value(comments, "DATE"));
+		if (!sd->year)
+			{
+			/* same */
+			sd->year = g_strdup(ogg123_comment_value(comments, "YEAR"));
+			}
+
+		track_text = ogg123_comment_value(comments, "TRACKNUMBER");
+		if (track_text)
+			{
+			sd->track = (guint8)strtol(track_text, NULL, 10);
+			}
 
 		path_list_free(comments);
 		}
