@@ -52,6 +52,14 @@
 
    ----------------------------------------------------------*/
 
+#ifndef RADIO_DEVICE 
+  #define RADIO_DEVICE "/dev/radio"
+#endif
+
+
+gchar *radio_device = NULL;
+
+
 /* these are set here, but should be overwritten in radio_real_test() */
 static double radio_limit_lower = 88.0;
 static double radio_limit_upper = 107.0;
@@ -103,16 +111,18 @@ static double radio_path_to_freq(const gchar *path);
 
 gint radio_enabled = TRUE;
 
-#ifndef RADIO_DEVICE
-  #define RADIO_DEVICE "/dev/radio"
-#endif
-
 static gint v4l_enabled = FALSE;	/* found, ioctl seems to work */
 static gint v4l_fd = -1;		/* /dev/radio fd */
 
+static const gchar *radio_device_get(void)
+{
+	if (radio_device) return radio_device;
+	return RADIO_DEVICE;
+}
+
 static void radio_error_message(void)
 {
-	printf("Error talking (ioctl) to %s, %s\n", RADIO_DEVICE, strerror(errno));
+	printf("Error talking (ioctl) to %s, %s\n", radio_device_get(), strerror(errno));
 }
 
 static guint radio_calc_steps(struct video_tuner *t)
@@ -131,9 +141,9 @@ static gint radio_control_on(void)
 {
 	if (v4l_fd != -1) return TRUE;
 
-	if ((v4l_fd = open(RADIO_DEVICE, O_RDONLY)) == -1)
+	if ((v4l_fd = open(radio_device_get(), O_RDONLY)) == -1)
 		{
-		printf("failed to open radio device %s, %s\n", RADIO_DEVICE, strerror(errno));
+		printf("failed to open radio device %s, %s\n", radio_device_get(), strerror(errno));
 		v4l_enabled = FALSE;
 		v4l_fd = -1;
 		return FALSE;
@@ -253,13 +263,14 @@ static gint radio_real_test()
 {
 	struct video_tuner t;
 
-	if (!isname(RADIO_DEVICE))
+	if (!isname(radio_device_get()))
 		{
-		printf(_("Failed to find %s\n"), RADIO_DEVICE);
+		printf(_("Failed to find %s\n"), radio_device_get());
 		v4l_enabled = FALSE;
 		return FALSE;
 		}
 
+	radio_control_off();
 	if (!radio_control_on())
 		{
 		v4l_enabled = FALSE;
@@ -403,7 +414,7 @@ gint radio_test(gint recheck)
 
 	if (!radio_enabled) return FALSE;
 
-	if (checked && (found || !recheck)) return found;
+	if (checked && !recheck) return found;
 	checked = TRUE;
 
 	if (debug_mode) printf("Checking for radio tuner...\n");
@@ -934,6 +945,8 @@ void radio_init(void)
 
 	if (debug_mode) printf("radio module initing...\n");
 
+	if (!radio_device) radio_device = g_strdup(RADIO_DEVICE);
+
 	imd = g_new0(IO_ModuleData, 1);
 
 	imd->title = "radio";
