@@ -298,6 +298,11 @@ const gchar *current_song_get_comment(void)
 	return playlist_data_get_comment(current_songdata);
 }
 
+gint current_song_get_track(void)
+{
+	return playlist_data_get_track(current_songdata);
+}
+
 /*
  *-----------------------------------------------------------------------------
  * the main loop! called 8 times per second (125 ms)
@@ -435,12 +440,12 @@ static gint update_condition(gpointer data)
 				{
 				status = STATUS_STOP;
 				playback_exec_command(EXEC_PLAY, current_song_get_data(), 0);
-				display_flyby_start();
 				}
 			else
 				{
 				current_song_set_to_next();
 				}
+			display_flyby_start();
 			}
 		else
 			{
