@@ -27,6 +27,7 @@ struct _SongInfoDialog
 	GtkWidget *year_entry;
 	GtkWidget *comment_entry;
 	GtkWidget *genre_combo;
+	GtkWidget *track_spin;
 	GtkWidget *save_button;
 	gchar *path;
 };
@@ -49,6 +50,7 @@ static void save_tag_pressed(GtkWidget *w, gpointer data)
 	const gchar *comment;
 	const gchar *genre_text;
 	guint8 genre = 0;
+	guint8 track;
 
         title = gtk_entry_get_text(GTK_ENTRY(s->title_entry));
         artist = gtk_entry_get_text(GTK_ENTRY(s->artist_entry));
@@ -56,18 +58,19 @@ static void save_tag_pressed(GtkWidget *w, gpointer data)
 	year = gtk_entry_get_text(GTK_ENTRY(s->year_entry));
 	comment = gtk_entry_get_text(GTK_ENTRY(s->comment_entry));
 	genre_text = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(s->genre_combo)->entry));
+	track = (guint8)gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(s->track_spin));
 
 	while (get_id3_genre(genre) && strcmp(get_id3_genre(genre), genre_text) != 0) genre++;
 	if (get_id3_genre(genre) == NULL) genre = 255;
 
-	set_id3_tag(s->path, title, artist, album, year, comment, genre);
+	set_id3_tag(s->path, title, artist, album, year, comment, genre, track);
 	
 	playlist_update_by_path(s->path);
 
 	gtk_widget_set_sensitive(s->save_button, FALSE);
 }
 
-static void data_changed_cb(GtkWidget *w, gpointer data)
+static void data_changed_cb(GtkObject *o, gpointer data)
 {
 	SongInfoDialog *s = data;
 
@@ -236,6 +239,9 @@ GtkWidget *mpg_create_info_window(const gchar *file)
 		s->comment_entry = songinfo_add_entry(vbox1, _("Comment"), d ? d->comment : NULL,
 						      30, GTK_SIGNAL_FUNC(data_changed_cb), s);
 
+		s->track_spin = songinfo_add_spin(vbox1, _("Track"), d ? (gint)d->track : 0,
+			       			  0, 255, GTK_SIGNAL_FUNC(data_changed_cb), s);
+
 		hbox = gtk_hbutton_box_new();
 		gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
 		gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 0);
