@@ -14,6 +14,7 @@
 #include "playlist-dlg.h"
 
 #include "playlist.h"
+#include "players.h"
 #include "types.h"
 #include "ui_fileops.h"
 #include "ui_tabcomp.h"
@@ -516,19 +517,15 @@ void playlist_dialog_load_file(const gchar *path, gint to_playlist)
 	g_free(filter);
 
 	i = 0;
-	while (i >= 0)
+	while (player_module_id_exists(i))
 		{
 		filter = filter_get_text_list_by_id(i);
 		if (filter)
 			{
 			file_dialog_add_filter(fd, filter, filter_get_description_by_id(i), FALSE);
 			g_free(filter);
-			i++;
-			}
-		else
-			{
-			i = -1;
 			}
+		i++;
 		}
 
 	fd->type = to_playlist;
