@@ -79,15 +79,43 @@ static void playlist_window_build(void);
  * based on code by "Michael Bruun Petersen" <mbp@image.dk>
  *-----------------------------------------------------------------------------
  */
- 
-#define MAX_PLAYLIST_VIEW_ELEMENTS 10
 
-static gint playlist_view_elements = 9;
-static gint playlist_view_config[MAX_PLAYLIST_VIEW_ELEMENTS] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 0};
-static gint playlist_view_widths[MAX_PLAYLIST_VIEW_ELEMENTS] = {6, 160, 100, 100, 30, 30, 60, 160, 160, 0};
+enum {
+	COLUMN_ICON = 0,
+	COLUMN_TITLE,
+	COLUMN_ALBUM,
+	COLUMN_ARTIST,
+	COLUMN_YEAR,
+	COLUMN_TIME,
+	COLUMN_GENRE,
+	COLUMN_FILENAME,
+	COLUMN_COMMENT,
+	COLUMN_TRACK,
+	COLUMN_ELEMENT_COUNT
+};
+
+/* width of each column, corresponds to enum numbers, above */
+static gint playlist_view_widths[COLUMN_ELEMENT_COUNT] = {6, 160, 100, 100, 30, 30, 60, 160, 160, 30};
+
+/* the column order, to change the order just rearrange this list */
+static gint playlist_view_config[COLUMN_ELEMENT_COUNT] = {
+	COLUMN_ICON,
+	COLUMN_TITLE,
+	COLUMN_ALBUM,
+	COLUMN_ARTIST,
+	COLUMN_YEAR,
+	COLUMN_TIME,
+	COLUMN_GENRE,
+	COLUMN_TRACK,
+	COLUMN_FILENAME,
+	COLUMN_COMMENT
+};
+
+/* sorting variables */
 static gint playlist_view_sort_column = -1;
 static gint playlist_view_sort_invert = 0;
 
+
 static void playlist_clist_construct_titles(gchar* titles[])
 {
 	/* it is easier to define this here, esp. for translations */
@@ -101,24 +129,37 @@ static void playlist_clist_construct_titles(gchar* titles[])
 					  _("Genre"),
 					  _("Filename"),
 					  _("Comment"),
+					  _("Track"),
 					  "",
-					  ""
 					  };
 	
 	gint i;
 
-	for (i = 0; i < playlist_view_elements; i++)
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 		{
 		titles[i] = playlist_element_names[playlist_view_config[i]];
 		}
 }
 
+static gint playlist_clist_column_lookup(gint type)
+{
+	gint i;
+
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
+		{
+		if (playlist_view_config[i] == type) return i;
+		}
+
+	return -1;
+}
+
 static gchar* playlist_clist_column_data(SongData* sd, gint column)
 {
 	static gchar *length_text = NULL;
+	static gchar *track_text = NULL;
 	gint view;
 
-	if (!sd || (column < 1) || (column >= playlist_view_elements))
+	if (!sd || (column < 0) || (column >= COLUMN_ELEMENT_COUNT) || column == COLUMN_ICON)
 		{
 		return "";
 		}
@@ -126,7 +167,7 @@ static gchar* playlist_clist_column_data(SongData* sd, gint column)
 	view = playlist_view_config[column];
 	switch (view)
 		{
-		case 1:
+		case COLUMN_TITLE:
 			if (sd->title)
 				{
 				return sd->title;
@@ -135,22 +176,27 @@ static gchar* playlist_clist_column_data(SongData* sd, gint column)
 				{
 				return (gchar *)filename_from_path(sd->path);
 				}
-		case 2:
+		case COLUMN_ALBUM:
 			return sd->album;
-		case 3:
+		case COLUMN_ARTIST:
 			return sd->artist;
-		case 4:
+		case COLUMN_YEAR:
 		        return sd->year;
-		case 5:
+		case COLUMN_TIME:
 			if (length_text) g_free(length_text);
 			length_text = playlist_data_get_time(sd);
 			return length_text ? length_text : "";
-		case 6:
+		case COLUMN_GENRE:
 			return sd->genre;
-		case 7:
+		case COLUMN_FILENAME:
 			return (gchar *)filename_from_path(sd->path);
-		case 8:
+		case COLUMN_COMMENT:
 			return sd->comment;
+		case COLUMN_TRACK:
+			if (sd->track == 0) return "";
+			if (track_text) g_free(track_text);
+			track_text = g_strdup_printf("%d", sd->track);
+			return track_text;
 		default:
 			return "";
 		}
@@ -165,14 +211,14 @@ static void playlist_clist_arrange_data(gint pos, gchar *buf[])
 
 	if (!sd)
 		{
-		for (i = 0; i < playlist_view_elements; i++)
+		for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 			{
 			buf[i] = "";
 			}
 		return;
 		}
 
-	for (i = 0; i < playlist_view_elements; i++)
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 		{
 		buf[i] = playlist_clist_column_data(sd, i);
 		}
@@ -181,7 +227,7 @@ static void playlist_clist_arrange_data(gint pos, gchar *buf[])
 static gint playlist_clist_append(GtkCList *clist, gint pos)
 {
 	gint row;
-	gchar *buf[MAX_PLAYLIST_VIEW_ELEMENTS];
+	gchar *buf[COLUMN_ELEMENT_COUNT];
 	playlist_clist_arrange_data(pos, buf);
 	row = gtk_clist_append(clist, buf);
 	playlist_window_update_song_flags(pos);
@@ -190,7 +236,7 @@ static gint playlist_clist_append(GtkCList *clist, gint pos)
 
 static void playlist_clist_insert(GtkCList *clist, gint pos)
 {
-	gchar *buf[MAX_PLAYLIST_VIEW_ELEMENTS];
+	gchar *buf[COLUMN_ELEMENT_COUNT];
 	playlist_clist_arrange_data(pos, buf);
 	gtk_clist_insert(clist, pos, buf);
 	playlist_window_update_song_flags(pos);
@@ -202,7 +248,7 @@ static void playlist_clist_update(GtkCList *clist, gint pos)
 	gint i;
 	SongData *sd = playlist_get_data(pos);
 
-	for (i = 0; i < playlist_view_elements; i++)
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 		{
 		text = playlist_clist_column_data(sd, i);
 		gtk_clist_set_text (clist, pos, i, text);
@@ -214,14 +260,24 @@ static gint playlist_sort_compare_func(gconstpointer a, gconstpointer b)
 {
 	gint result;
 	gchar *sa, *sb;
+	gint column;
 
-	if (playlist_view_config[playlist_view_sort_column] == 5) /* playlist_clist_column_data
-					       returns static for this item */
+	column = playlist_view_config[playlist_view_sort_column];
+
+	if (column == COLUMN_TIME || column == COLUMN_TRACK)
 		{
 		gint al, bl;
 
-		al = ((SongData*)a)->length;
-		bl = ((SongData*)b)->length;
+		if (column == COLUMN_TIME)
+			{
+			al = ((SongData*)a)->length;
+			bl = ((SongData*)b)->length;
+			}
+		else
+			{
+			al = ((SongData*)a)->track;
+			bl = ((SongData*)b)->track;
+			}
 
 		if (al < bl)
 			result = -1;
@@ -341,11 +397,11 @@ void playlist_window_update_song_icon_by_flags(gint n, SongFlags flags)
 
 	if (pixmap)
 		{
-		gtk_clist_set_pixmap(GTK_CLIST(playlist_clist), n, 0, pixmap, mask);
+		gtk_clist_set_pixmap(GTK_CLIST(playlist_clist), n, COLUMN_ICON, pixmap, mask);
 		}
-	else if (gtk_clist_get_cell_type(GTK_CLIST(playlist_clist), n, 0) != GTK_CELL_TEXT)
+	else if (gtk_clist_get_cell_type(GTK_CLIST(playlist_clist), n, COLUMN_ICON) != GTK_CELL_TEXT)
 		{
-		gtk_clist_set_text(GTK_CLIST(playlist_clist), n, 0, "");
+		gtk_clist_set_text(GTK_CLIST(playlist_clist), n, COLUMN_ICON, "");
 		}
 }
 
@@ -912,6 +968,7 @@ void plw_filelist_add_pressed(void)
 
 	if (!list) return;
 
+	gtk_clist_freeze(GTK_CLIST(playlist_clist));
 	work = list;
 	while(work)
 		{
@@ -922,6 +979,7 @@ void plw_filelist_add_pressed(void)
 			}
 		work = work->next;
 		}
+	gtk_clist_thaw(GTK_CLIST(playlist_clist));
 
 	path_list_free(list);
 }
@@ -938,6 +996,7 @@ void plw_filelist_insert_pressed(void)
 
 	if (row == -1) row = 0;
 
+	gtk_clist_freeze(GTK_CLIST(playlist_clist));
 	work = list;
 	while(work)
 		{
@@ -949,6 +1008,7 @@ void plw_filelist_insert_pressed(void)
 			}
 		work = work->next;
 		}
+	gtk_clist_thaw(GTK_CLIST(playlist_clist));
 
 	path_list_free(list);
 }
@@ -1004,7 +1064,8 @@ static gint plw_edit_title_cb(ClistEditData *ced, const gchar *old, const gchar
 void plw_playlist_edit_title_pressed(void)
 {
 	gint row = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(playlist_clist)));
-	clist_edit_by_row(GTK_CLIST(playlist_clist), row, 1, plw_edit_title_cb, playlist_get_data(row));
+	clist_edit_by_row(GTK_CLIST(playlist_clist), row, playlist_clist_column_lookup(COLUMN_TITLE),
+			  plw_edit_title_cb, playlist_get_data(row));
 }
 
 static gint plw_edit_comment_cb(ClistEditData *ced, const gchar *old, const gchar *new, gpointer data)
@@ -1022,7 +1083,8 @@ static gint plw_edit_comment_cb(ClistEditData *ced, const gchar *old, const gcha
 void plw_playlist_edit_comment_pressed(void)
 {
 	gint row = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(playlist_clist)));
-	clist_edit_by_row(GTK_CLIST(playlist_clist), row, 8, plw_edit_comment_cb, playlist_get_data(row));
+	clist_edit_by_row(GTK_CLIST(playlist_clist), row, playlist_clist_column_lookup(COLUMN_COMMENT),
+			  plw_edit_comment_cb, playlist_get_data(row));
 }
 
 void plw_playlist_move_pressed(void)
@@ -1095,15 +1157,48 @@ void plw_playlist_remove_pressed(void)
 {
 	GList *list = playlist_selection_get_number_list(TRUE);
 	GList *work;
+	gint row;
 
 	if (!list) return;
 
+	/* check that the current song is about to be removed,
+	 * if so note next unselected song and set current song to NULL
+	 */
+	row = current_song_get_number();
+	if (row >= 0 && clist_row_is_selected(GTK_CLIST(playlist_clist), row))
+		{
+		gint new_row;
+
+		new_row = playlist_get_next(row);
+		while (new_row >= 0 && clist_row_is_selected(GTK_CLIST(playlist_clist), new_row))
+			{
+			new_row = playlist_get_next(new_row);
+			}
+		if (new_row == -1)
+			{
+			new_row = playlist_get_prev(row);
+			while (new_row >= 0 && clist_row_is_selected(GTK_CLIST(playlist_clist), new_row))
+				{
+				new_row = playlist_get_prev(new_row);
+				}
+			}
+
+		current_song_set(new_row, NULL);
+		}
+
+	display_freeze();
+	gtk_clist_freeze(GTK_CLIST(playlist_clist));
 	work = g_list_last(list);
-	while(work)
+	while (work)
 		{
 		playlist_remove(NULL, GPOINTER_TO_INT(work->data), FALSE);
 		work = work->prev;
 		}
+	gtk_clist_thaw(GTK_CLIST(playlist_clist));
+	display_thaw();
+	display_set_song_count(playlist_get_count());
+	display_set_song_number(current_song_get_number());
+	display_playlist_refresh();
 
 	if (GPOINTER_TO_INT(list->data) < playlist_get_count())
 		{
@@ -1415,7 +1510,7 @@ static void update_history_menu(gchar *path)
 	button = gtk_menu_item_new_with_label("/");
 
 	gtk_signal_connect(GTK_OBJECT(button), "activate",
-			   GTK_SIGNAL_FUNC(history_menu_select), path);
+			   GTK_SIGNAL_FUNC(history_menu_select), "/");
 
 	gtk_menu_append(GTK_MENU (historymenu), button);
 	gtk_widget_show(button);
@@ -1934,10 +2029,15 @@ void playlist_window_hide(void)
 	window_list_div_dir = s_scrolled->allocation.height;
 	window_list_div_mid = s_hbox->allocation.width;
 
-	for (i = 1; i < playlist_view_elements; i++)
+	for (i = 1; i < COLUMN_ELEMENT_COUNT; i++)
 		{
 		gchar *tmp;
-		gint w = GTK_CLIST(playlist_clist)->column[(i)].width;
+		gint w;
+		gint c = 0;
+
+		c = playlist_clist_column_lookup(i);
+		w = GTK_CLIST(playlist_clist)->column[c].width;
+
 		tmp = buf;
 		if (!tmp)
 			{
@@ -1976,10 +2076,11 @@ static void playlist_window_build(void)
 
 	gchar *dir_title [] = { _("Directories:"), };
 	gchar *file_title [] = { _("Files:"), };
-	gchar *play_title[MAX_PLAYLIST_VIEW_ELEMENTS];
+	gchar *play_title[COLUMN_ELEMENT_COUNT];
 	gchar *buf;
 	gint i;
-	gint playlist_column_widths[10];
+	gint playlist_column_widths[COLUMN_ELEMENT_COUNT];
+	gint playlist_aligned_widths[COLUMN_ELEMENT_COUNT];
 	gint *column_widths;
 
 	/* set up playlist window */
@@ -2234,7 +2335,7 @@ static void playlist_window_build(void)
 
 	/* play list */
 	playlist_clist_construct_titles(play_title);
-	playlist_clist = gtk_clist_new_with_titles(playlist_view_elements, play_title);
+	playlist_clist = gtk_clist_new_with_titles(COLUMN_ELEMENT_COUNT, play_title);
 	gtk_clist_set_selection_mode(GTK_CLIST(playlist_clist), GTK_SELECTION_EXTENDED);
 
 	gtk_signal_connect(GTK_OBJECT(playlist_clist), "button_press_event",
@@ -2243,22 +2344,30 @@ static void playlist_window_build(void)
 			   GTK_SIGNAL_FUNC(playlist_select_row_cb), NULL);
 	gtk_widget_set_usize(playlist_clist, list_width * 2, -1);
 
-	gtk_clist_set_column_width(GTK_CLIST(playlist_clist), 0, playlist_view_widths[0]);
-
-	if (slik_remember_position && window_list_columns &&
-	    sscanf(window_list_columns, "%d, %d, %d, %d, %d, %d, %d, %d", 
-	    &playlist_column_widths[1], &playlist_column_widths[2],
-	    &playlist_column_widths[3], &playlist_column_widths[4], &playlist_column_widths[5],
-	    &playlist_column_widths[6], &playlist_column_widths[7], &playlist_column_widths[8]) == 8)
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 		{
-		column_widths = playlist_column_widths;
+		playlist_column_widths[i] = playlist_view_widths[i];
+		}
+	if (slik_remember_position && window_list_columns &&
+	    sscanf(window_list_columns, "%d, %d, %d, %d, %d, %d, %d, %d, %d",
+	    &playlist_column_widths[1], &playlist_column_widths[2], &playlist_column_widths[3],
+	    &playlist_column_widths[4], &playlist_column_widths[5], &playlist_column_widths[6],
+	    &playlist_column_widths[7], &playlist_column_widths[8], &playlist_column_widths[9]) >= 8)
+		{
+		/* reorder them to internal order */
+		for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
+			{
+			gint c = playlist_view_config[i];
+			playlist_aligned_widths[i] = playlist_column_widths[c];
+			}
+		column_widths = playlist_aligned_widths;
 		}
 	else
 		{
 		column_widths = playlist_view_widths;
 		}
 
-	for (i = 1; i < playlist_view_elements; i++)
+	for (i = 0; i < COLUMN_ELEMENT_COUNT; i++)
 		{
 		gtk_clist_set_column_width(GTK_CLIST(playlist_clist), i, column_widths[i]);
 		}
@@ -2266,8 +2375,8 @@ static void playlist_window_build(void)
 	gtk_signal_connect(GTK_OBJECT(playlist_clist), "click_column",
 			   GTK_SIGNAL_FUNC(playlist_clist_column_clicked),
 			   NULL);
-	gtk_clist_column_title_passive(GTK_CLIST(playlist_clist), 0);
-	gtk_clist_set_column_resizeable(GTK_CLIST(playlist_clist), 0, FALSE);
+	gtk_clist_column_title_passive(GTK_CLIST(playlist_clist), COLUMN_ICON);
+	gtk_clist_set_column_resizeable(GTK_CLIST(playlist_clist), COLUMN_ICON, FALSE);
 
 	gtk_container_add (GTK_CONTAINER (scrolled), playlist_clist);
 	gtk_widget_show (playlist_clist);
