@@ -948,6 +948,12 @@ const gchar *playlist_data_get_comment(SongData *sd)
 	return sd->comment;
 }
 
+gint playlist_data_get_track(SongData *sd)
+{
+	if (!sd) return 0;
+	return (gint)sd->track;
+}
+
 gchar *playlist_data_get_time(SongData *sd)
 {
 	if (!sd) return NULL;
@@ -1122,6 +1128,12 @@ const gchar *playlist_get_comment(gint n)
 	return (playlist_data_get_comment(sd));
 }
 
+gint playlist_get_track(gint n)
+{
+	SongData *sd = playlist_get_data(n);
+	return (playlist_data_get_track(sd));
+}
+
 gchar *playlist_get_time(gint n)
 {
 	SongData *sd = playlist_get_data(n);
