@@ -14,6 +14,7 @@
 #include "preset-dlg.h"
 
 #include "display.h"
+#include "players.h"
 #include "types.h"
 #include "ui_fileops.h"
 #include "ui_utildlg.h"
@@ -96,19 +97,15 @@ void preset_dialog(const gchar *path, gint playlist)
 	g_free(filter);
 
 	i = 0;
-	while (i >= 0)
+	while (player_module_id_exists(i))
 		{
 		filter = filter_get_text_list_by_id(i);
 		if (filter)
 			{
 			file_dialog_add_filter(fd, filter, filter_get_description_by_id(i), FALSE);
 			g_free(filter);
-			i++;
-			}
-		else
-			{
-			i = -1;
 			}
+		i++;
 		}
 
 	hbox = gtk_hbutton_box_new();
