@@ -233,7 +233,7 @@ static void parse_number(gchar **vector, gint length, const gchar *dirpath,
 			}
 		}
 
-	number = number_new(digit, x, y, num_length, zeros, center);
+	number = number_new(digit, x, y, num_length, zeros, center, 0);
 	digit_unref(digit);
 
 	if (number)
@@ -330,12 +330,17 @@ static void parse_text(gchar **vector, gint length, const gchar *dirpath,
 	p++;
 
 
-	text = text_new_from_file(filename, x, y, text_length, FALSE, extended);
+	text = text_new_from_file(filename, x, y, text_length, FALSE, 0, extended);
 
 	if (text)
 		{
 		WidgetData *wd;
 
+		/* text length is now specified in pixels instead of characters  */
+		text->width = text_length * text->font->char_width;
+		gdk_pixbuf_unref(text->pixbuf);
+		text->pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, text->width, text->height);
+
 		wd = text_register(skin, text, id, NULL);
 
 		if (edit)
