@@ -71,8 +71,12 @@ static TextData *wamp_text(gchar *path, gint l, gint x, gint y, SkinData *skin)
 
 	gdk_pixbuf_unref(pb_temp);
 
+	/* backwards compatibility, new width is pixels instead of chars,
+	 * winamp chars are 5 pixels wide */
+	l *= 5;
+
 	font = font_new(pb, FALSE);
-	text = text_new(font, x, y, l, FALSE);
+	text = text_new(font, x, y, l, FALSE, 0);
 	font_unref(font);
 	text_register(skin, text, "title", NULL);
 
@@ -384,7 +388,7 @@ static void wamp_number(DigitData *digit, gint length, gint zeros, gint center,
 {
 	NumberData *number;
 
-	number = number_new(digit, x, y, length, zeros, center);
+	number = number_new(digit, x, y, length, zeros, center, 0);
 	number_register(skin, number, key, NULL);
 }
 
