@@ -156,3 +156,33 @@ GtkWidget *songinfo_add_entry(GtkWidget *vbox, const gchar *label, const gchar *
 	return entry;
 }
 
+GtkWidget *songinfo_add_spin(GtkWidget *vbox, const gchar *label, gint value,
+			     gint lower, gint upper, GtkSignalFunc change_cb, gpointer data)
+{
+	GtkObject *adj;
+	GtkWidget *spin;
+	GtkWidget *wlabel;
+	GtkWidget *hbox;
+	gchar *buf;
+
+	hbox = gtk_hbox_new(FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	gtk_widget_show(hbox);
+
+	buf = g_strconcat(label, ":", NULL);
+	wlabel = gtk_label_new(buf);
+	g_free(buf);
+	gtk_box_pack_start(GTK_BOX(hbox), wlabel, FALSE, FALSE, 0);
+	gtk_widget_show(wlabel);
+
+	adj = gtk_adjustment_new((gfloat)value, (gfloat)lower, (gfloat)upper, 1.0, 1.0, 1.0);
+	spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1.0, 0);
+	gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(spin), GTK_UPDATE_ALWAYS);
+	gtk_box_pack_end(GTK_BOX(hbox), spin, FALSE, FALSE, 0);
+	gtk_widget_show(spin);
+
+	gtk_signal_connect(GTK_OBJECT(adj), "value_changed", change_cb, data);
+
+	return spin;
+}
+
