@@ -140,6 +140,9 @@ DialData *dial_new(GdkPixbuf *pb, gint x, gint y,
 	dial->center_x = center_x;
 	dial->center_y = center_y;
 
+	dial->fixed_handle = FALSE;
+	dial->fixed_radius = 0;
+
 	if (dial->reversed)
 		{
 		dial->position = dial->angle_length;
@@ -249,6 +252,14 @@ DialData *dial_new_from_file(const gchar *file, gint x, gint y,
 			clip_w, clip_h, clip_pb, item_key);
 }
 
+void dial_set_fixed_handle(DialData *dial, gint fixed, gint radius)
+{
+	if (!dial) return;
+
+	dial->fixed_handle = fixed;
+	dial->fixed_radius = radius;
+}
+
 void dial_free(DialData *dial)
 {
 	if (!dial) return;
@@ -316,11 +327,29 @@ static void real_dial_render(DialData *dial, GdkPixbuf *pb, UIData *ui)
 
 	handle = dial_get_handle_pixbuf(dial, dial->pushed, dial->prelit);
 
-	pixbuf_copy_rotate_alpha_with_clipping(handle, dial->offset_x, dial->offset_y,
-					       pb, dial->center_x, dial->center_y,
-					       (double)((float)dial->angle_start + dial->position + 90.0),
-					       dial->x, dial->y, dial->width, dial->height,
-					       dial->clip_mask ? dial->pixbuf : NULL);
+	if (dial->fixed_handle && dial->fixed_radius > 0)
+		{
+		gint x, y;
+		double theta;
+
+		theta = ((double)dial->angle_start + dial->position + 90.0) / 180.0 * PI;
+		x = dial->center_x + (sin(theta) * (double)dial->fixed_radius) - dial->offset_x;
+		y = dial->center_y - (cos(theta) * (double)dial->fixed_radius) - dial->offset_y;
+
+		pixbuf_copy_area_alpha_with_clipping(handle, 0, 0,
+						     pb, x, y,
+						     dial->handle_width, dial->handle_height, 255,
+						     dial->x, dial->y, dial->width, dial->height,
+						     dial->clip_mask ? dial->pixbuf : NULL);
+		}
+	else
+		{
+		pixbuf_copy_rotate_alpha_with_clipping(handle, dial->offset_x, dial->offset_y,
+						       pb, dial->center_x, dial->center_y,
+						       (double)((float)dial->angle_start + dial->position + 90.0),
+						       dial->x, dial->y, dial->width, dial->height,
+						       dial->clip_mask ? dial->pixbuf : NULL);
+		}
 
 	ui_display_render_area(ui, dial->x, dial->y, dial->width, dial->height, NULL);
 }
@@ -543,8 +572,17 @@ static gint dial_hit_test(DialData *dial, gint x, gint y)
 	if (dial->clip_mask && !pixbuf_pixel_is_visible(dial->pixbuf, x - dial->x, y - dial->y)) return FALSE;
 
 	theta = (dial->angle_start + dial->position + 90.0) / 180.0 * PI;
-	hx = (float)dial->offset_x - 0.25 - ((dial->center_x - x) * cos(theta) - (y - dial->center_y) * sin(theta));
-	hy = (float)dial->offset_y - 0.25 + ((dial->center_x - x) * sin(theta) + (y - dial->center_y) * cos(theta));
+
+	if (dial->fixed_handle)
+		{
+		hx = dial->offset_x - ((dial->center_x - x) + (sin(theta) * (double)dial->fixed_radius));
+		hy = dial->offset_y - ((dial->center_y - y) - (cos(theta) * (double)dial->fixed_radius));
+		}
+	else
+		{
+		hx = (float)dial->offset_x - 0.25 - ((dial->center_x - x) * cos(theta) - (y - dial->center_y) * sin(theta));
+		hy = (float)dial->offset_y - 0.25 + ((dial->center_x - x) * sin(theta) + (y - dial->center_y) * cos(theta));
+		}
 
 	pb = dial_get_handle_pixbuf(dial, dial->pushed, dial->prelit);
 
@@ -700,6 +738,8 @@ static WidgetData *dial_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	gint clip_w, clip_h;
 	gchar *clip_file;
 	gint clip_success;
+	gint fixed_handle;
+	gint fixed_radius;
 	const gchar *item_key;
 
 	/* req */
@@ -734,6 +774,8 @@ static WidgetData *dial_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	prelight = key_list_read_bool(list, "prelight");
 	reverse = key_list_read_bool(list, "reversed");
 	item_key = key_list_read_chars(list, "item_link", NULL);
+	fixed_handle = key_list_read_bool(list, "fixed_handle");
+	if (!key_list_read_int(list, "fixed_radius", &fixed_radius)) fixed_radius = 0;
 
 	dial = dial_new_from_file(filename, x, y,
 				  center_x, center_y,
@@ -742,6 +784,10 @@ static WidgetData *dial_parse(SkinData *skin, GList *list, const gchar *skin_dir
 				  clip_w, clip_h, clip_file, item_key);
 	if (dial)
 		{
+		if (fixed_handle && fixed_radius > 0)
+			{
+			dial_set_fixed_handle(dial, fixed_handle, fixed_radius);
+			}
 		wd = dial_register(skin, dial, key, NULL);
 
 		if (edit)
