@@ -39,6 +39,8 @@ struct _DialDetail
 	GtkWidget *spin_clip_h;
 	GtkWidget *has_press_button;
 	GtkWidget *prelight_button;
+	GtkWidget *fixed_button;
+	GtkWidget *radius_spin;
 
 	WidgetData *wd;
 	UIData *ui;
@@ -67,6 +69,9 @@ struct _DialListData
 	gint reversed;
 	gchar *clip_mask;
 
+	gint fixed_handle;
+	gint fixed_radius;
+
 	gchar *item_key;
 };
 
@@ -91,6 +96,9 @@ struct _DialPage
 	GtkWidget *has_press_button;
 	GtkWidget *has_prelight_button;
 
+	GtkWidget *fixed_button;
+	GtkWidget *radius_spin;
+
 	GtkWidget *clip_mask_entry;
 	GtkWidget *item_key_entry;
 
@@ -148,6 +156,12 @@ static void dial_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 	if (clip_mask) ui_edit_write_key_char(f, "clip_mask", clip_mask);
 	if (dial->item_key) ui_edit_write_key_char(f, "item_link", dial->item_key);
 
+	if (dial->fixed_handle)
+		{
+		ui_edit_write_key_bool(f, "fixed_handle", dial->fixed_handle);
+		ui_edit_write_key_int(f, "fixed_radius", dial->fixed_radius);
+		}
+
 	g_free(image);
 	g_free(clip_mask);
 }
@@ -196,6 +210,9 @@ static gpointer dial_edit_read(UIData *ui, WidgetData *wd, GList *list)
 	dd->clip_mask = g_strdup(ui_widget_get_data(wd, "clip_mask"));
 	dd->item_key = g_strdup(dial->item_key);
 
+	dd->fixed_handle = dial->fixed_handle;
+	dd->fixed_radius = dial->fixed_radius;
+
 	dd->key = g_strdup(wd->key);
 	dd->data = g_strdup(ui_widget_get_data(wd, "data"));
 	dd->text_id = g_strdup(wd->text_id);
@@ -336,6 +353,26 @@ static void dial_edit_props_spin_cb(GtkAdjustment *adjustment, gpointer data)
 	ui_widget_draw(dd->ui, dd->wd, update, TRUE);
 }
 
+static void dial_edit_props_radius_cb(GtkAdjustment *adjustment, gpointer data)
+{
+	DialDetail *dd = data;
+
+	dd->dial->fixed_radius = ui_edit_spin_get(dd->radius_spin);
+
+	ui_widget_draw(dd->ui, dd->wd, TRUE, TRUE);
+}
+
+static void dial_edit_props_fixed_cb(GtkWidget *widget, gpointer data)
+{
+	DialDetail *dd = data;
+
+	dd->dial->fixed_handle = ui_edit_toggle_get(dd->fixed_button);
+	ui_edit_frame_sensitive(dd->radius_spin, dd->dial->fixed_handle, TRUE);
+	if (dd->dial->fixed_handle && dd->dial->fixed_radius < 1) dd->dial->fixed_radius = 1;
+
+	ui_widget_draw(dd->ui, dd->wd, TRUE, TRUE);
+}
+
 static gpointer dial_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpointer detail)
 {
 	DialData *dial = wd->widget;
@@ -403,6 +440,15 @@ static gpointer dial_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
+		
+		dd->fixed_button = ui_edit_toggle_new(hbox, _("Fixed handle"));
+		gtk_signal_connect(GTK_OBJECT(dd->fixed_button), "clicked",
+				   GTK_SIGNAL_FUNC(dial_edit_props_fixed_cb), dd);
+		dd->radius_spin = ui_edit_spin_new(hbox, _("Radius:"), 1, 2000, &adj);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(dial_edit_props_radius_cb), dd);
+
+		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
 		dd->item_key_entry = ui_edit_entry_new(hbox, _("Item link key:"));
 		gtk_signal_connect(GTK_OBJECT(dd->item_key_entry), "changed",
@@ -433,6 +479,10 @@ static gpointer dial_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 	ui_edit_spin_set_blocking(dd->spin_clip_w, dial->width, dd);
 	ui_edit_spin_set_blocking(dd->spin_clip_h, dial->height, dd);
 
+	ui_edit_toggle_set_blocking(dd->fixed_button, dial->fixed_handle, dd);
+	ui_edit_frame_sensitive(dd->radius_spin, dial->fixed_handle, TRUE);
+	ui_edit_spin_set_blocking(dd->radius_spin, dial->fixed_radius, dd);
+
 	return dd;
 }
 
@@ -471,6 +521,9 @@ static void dial_edit_page_add_cb(GtkWidget *widget, gpointer data)
 				  ui_edit_spin_get(pd->clip_w_spin),
 				  ui_edit_spin_get(pd->clip_h_spin),
 				  clip_mask, item_key);
+	dial_set_fixed_handle(dial,
+		              ui_edit_toggle_get(pd->fixed_button),
+			      ui_edit_spin_get(pd->radius_spin));
 	if (dial)
 		{
 		WidgetData *wd;
@@ -507,6 +560,9 @@ static void dial_edit_page_sync(DialPage *pd, DialListData *dd)
 	ui_edit_spin_set(pd->offset_x_spin, dd->offset_x);
 	ui_edit_spin_set(pd->offset_y_spin, dd->offset_y);
 
+	ui_edit_toggle_set(pd->fixed_button, dd->fixed_handle);
+	ui_edit_spin_set(pd->radius_spin, dd->fixed_radius);
+
 	ui_edit_entry_set(pd->clip_mask_entry, dd->clip_mask);
 	ui_edit_entry_set(pd->item_key_entry, dd->item_key);
 }
@@ -530,6 +586,13 @@ static void dial_edit_page_clip_cb(GtkWidget *entry, gpointer data)
 	ui_edit_frame_sensitive(pd->clip_w_spin, state, FALSE);
 }
 
+static void dial_edit_page_fixed_cb(GtkWidget *widget, gpointer data)
+{
+	DialPage *pd = data;
+
+	ui_edit_frame_sensitive(pd->radius_spin, ui_edit_toggle_get(pd->fixed_button), TRUE);
+}
+
 static void dial_edit_page_destroy_cb(GtkWidget *widget, gpointer data)
 {
 	DialPage *pd = data;
@@ -590,6 +653,13 @@ static GtkWidget *dial_edit_page_new(EditData *ed)
 	pd->offset_x_spin = ui_edit_spin_new(frame, _("x:"), -2000, 2000, NULL);
 	pd->offset_y_spin = ui_edit_spin_new(frame, _("y:"), -2000, 2000, NULL);
 
+	frame = ui_edit_frame_new(vbox, FALSE, NULL);
+	pd->fixed_button = ui_edit_toggle_new(frame, _("Fixed handle"));
+	gtk_signal_connect(GTK_OBJECT(pd->fixed_button), "clicked",
+			   GTK_SIGNAL_FUNC(dial_edit_page_fixed_cb), pd);
+	pd->radius_spin = ui_edit_spin_new(frame, _("Radius:"), 1, 2000, NULL);
+	ui_edit_frame_sensitive(pd->radius_spin, FALSE, TRUE);
+
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_dial_image");
 	pd->pixmap = ui_edit_pixmap_new(vbox);
 	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
