@@ -54,7 +54,7 @@ void ui_display_render_area(UIData *ui, gint x, gint y, gint w, gint h, WidgetDa
 
 	if (!pixbuf || !pixmap || !ui->display->window) return;
 
-	if (wd && wd == ui->focus_widget && slik_focus_enable &&
+	if (wd && wd == ui->focus_widget && (slik_focus_enable || ui->focus_enable) &&
 	    GTK_WIDGET_HAS_FOCUS(ui->display))
 		{
 		gint wx, wy, ww, wh;
@@ -312,7 +312,7 @@ static WidgetData *ui_display_focus_nearest(UIData *ui, gint x, gint y)
 	gint dx, dy;
 	GList *work;
 
-	if (!slik_focus_enable) return NULL;
+	if (!slik_focus_enable && !ui->focus_enable) return NULL;
 
 	dx = ui->skin->width;
 	dy = ui->skin->height;
@@ -403,7 +403,7 @@ static WidgetData *ui_display_focus_find(UIData *ui, WidgetData *current, gint x
 	WidgetData *wd = NULL;
 	gint cx, cy, cw, ch;
 
-	if (!slik_focus_enable) return NULL;
+	if (!slik_focus_enable && !ui->focus_enable) return NULL;
 
 	if (x_dir == 0 && y_dir == 0) return current;
 
@@ -536,7 +536,7 @@ static gint ui_display_focus_move(UIData *ui, UIMoveFocusType focus)
 	WidgetData *new_widget;
 	gint x, y, w, h;
 
-	if (!slik_focus_enable) return FALSE;
+	if (!slik_focus_enable && !ui->focus_enable) return FALSE;
 
 	new_widget = NULL;
 	switch (focus)
@@ -583,7 +583,24 @@ static gint ui_display_key_press(GtkWidget *w, GdkEventKey *event, gpointer data
 	UIData *ui = data;
 	gint ret = FALSE;
 
-	if (!ui->skin || !slik_focus_enable) return FALSE;
+	if (!ui->skin) return FALSE;
+
+	/* pop up menus should work _always_, so test before poss. bail out */
+	if (event->keyval == GDK_F10 ||
+	    event->keyval == GDK_Menu)
+		{
+		if (ui->click_func)
+			{
+			/* hmm, perhaps the function table needs a menu callback
+			 * instead of synthesizing a button 3 press ? 
+			 */
+			ui->click_func(ui, 3, event->time, ui->click_data);
+			}
+		return TRUE;
+		}
+
+	if (!slik_focus_enable && !ui->focus_enable) return FALSE;
+
 	if (ui->active_widget) return FALSE;
 
 	if (ui->focus_widget &&
@@ -613,16 +630,6 @@ static gint ui_display_key_press(GtkWidget *w, GdkEventKey *event, gpointer data
 			case GDK_Tab:
 				ret = ui_display_focus_move(ui, UI_FOCUS_TAB_FORWARD);
 				break;
-			case GDK_F10:
-				if (ui->click_func)
-					{
-					/* hmm, perhaps the function table needs a menu callback
-					 * instead of synthesizing a button press ? 
-					 */
-					ui->click_func(ui, 3, event->time, ui->click_data);
-					}
-				ret = TRUE;
-				break;
 			default:
 				break;
 			}
@@ -639,7 +646,7 @@ static gint ui_display_focus_in(GtkWidget *widget, GdkEventFocus *event, gpointe
 
 	GTK_WIDGET_SET_FLAGS(widget, GTK_HAS_FOCUS);
 
-	if (!ui->skin || !slik_focus_enable) return FALSE;
+	if (!ui->skin || (!slik_focus_enable && !ui->focus_enable)) return FALSE;
 
 	if (!ui->focus_widget) ui->focus_widget = ui_display_focus_next(ui, NULL, TRUE);
 	if (ui->focus_widget)
@@ -661,7 +668,7 @@ static gint ui_display_focus_out(GtkWidget *widget, GdkEventFocus *event, gpoint
 
 	GTK_WIDGET_UNSET_FLAGS(widget, GTK_HAS_FOCUS);
 
-	if (!ui->skin || !slik_focus_enable) return FALSE;
+	if (!ui->skin || (!slik_focus_enable && !ui->focus_enable)) return FALSE;
 
 	if (ui->focus_widget)
 		{
@@ -749,8 +756,12 @@ static gint ui_display_pressed(GtkWidget *w, GdkEventButton *event, gpointer dat
 
 	if (event->button >= 2)
 		{
-		if (ui->click_func) ui->click_func(ui, event->button, event->time, ui->click_data);
-		return TRUE;
+		if (ui->click_func)
+			{
+			ui->click_func(ui, event->button, event->time, ui->click_data);
+			return TRUE;
+			}
+		return FALSE;
 		}
 
 	if (event->type != GDK_BUTTON_PRESS) return FALSE;
@@ -768,7 +779,7 @@ static gint ui_display_pressed(GtkWidget *w, GdkEventButton *event, gpointer dat
 			ui->active_widget = work->data;
 			if (debug_mode) printf("pressed widget: \"%s\" (%d)\n", ui->active_widget->key, ui->active_widget->type);
 
-			if (slik_focus_enable &&
+			if ((slik_focus_enable || ui->focus_enable) &&
 			    ui_widget_can_focus(ui->active_widget))
 				{
 				if (ui->focus_widget != ui->active_widget)
@@ -797,9 +808,10 @@ static gint ui_display_pressed(GtkWidget *w, GdkEventButton *event, gpointer dat
 		ui->in_move = TRUE;
 		gdk_window_get_pointer (NULL, &ui->press_root_x, &ui->press_root_y, &modmask);
 		}
-	ui->in_press = TRUE;
+	ui->in_press = (event->x >= 0 && event->x <= ui->skin->width &&
+			event->y >= 0 && event->y <= ui->skin->height);
 
-	return TRUE;
+	return ui->in_press;
 }
 
 static gint ui_display_released(GtkWidget *w, GdkEventButton *event, gpointer data)
@@ -836,7 +848,7 @@ static gint ui_display_released(GtkWidget *w, GdkEventButton *event, gpointer da
 	ui->in_press = FALSE;
 	ui->in_move = FALSE;
 
-	return TRUE;
+	return FALSE;
 }
 
 static void ui_display_leave(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
