@@ -111,12 +111,20 @@ ListData *list_new(GdkPixbuf *pb, gint x, gint y, gint w, gint h, gint sizeable,
 
 	ld->columns_right_justify = FALSE;
 
+	ld->font = NULL;
+	ld->text_r = 0;
+	ld->text_g = 0;
+	ld->text_b = 0;
+	ld->text_a = 255;
+
 	ld->overlay = util_size_pixbuf(pb, TRUE);
 
 	ld->timeout_id = -1;
 	ld->row_prelight = -1;
 	ld->row_press = -1;
 	ld->focus_row = -1;
+
+	ld->scroll_idle_id = -1;
 	
 	return ld;
 }
@@ -184,14 +192,34 @@ void list_image_row_flag(ListData *ld, GdkPixbuf *pb, gint sections, gint column
 	ld->flag_height = gdk_pixbuf_get_height(ld->flag_overlay) / sections;
 }
 
-void list_image_text(ListData *ld, GdkPixbuf *pb, gint extended)
+void list_set_font(ListData *ld, const gchar *description, GdkPixbuf *pb, gint extended,
+		   guint8 r, guint8 g, guint8 b, guint8 a)
 {
-	if (!ld || !pb) return;
+	if (!ld || (!description && !pb)) return;
 
-	ld->text_extended = extended;
-	ld->text_overlay = util_size_pixbuf(pb, TRUE);
-	ld->char_width = gdk_pixbuf_get_width(ld->text_overlay) / 32;
-	ld->char_height = gdk_pixbuf_get_height(ld->text_overlay) / (extended ? 6 : 3);
+	ld->text_r = r;
+	ld->text_g = g;
+	ld->text_b = b;
+	ld->text_a = a;
+	
+	if (ld->font) return;
+
+	if (pb)
+		{
+		ld->font = font_new(pb, extended);
+
+		/* no need to pad text end with spaces for lists */
+		if (ld->font) ld->font->fill = FALSE;
+		}
+	else
+		{
+		ld->font = font_new_from_x(description);
+		}
+
+	if (!ld->font)
+		{
+		printf("ui2_list.c: warning failed to create font for list\n");
+		}
 }
 
 void list_free(ListData *ld)
@@ -201,6 +229,7 @@ void list_free(ListData *ld)
 	if (!ld) return;
 
 	if (ld->timeout_id != -1) gtk_timeout_remove(ld->timeout_id);
+	if (ld->scroll_idle_id != -1) gtk_idle_remove(ld->scroll_idle_id);
 
 	if (ld->overlay) gdk_pixbuf_unref(ld->overlay);
 	if (ld->pixbuf) gdk_pixbuf_unref(ld->pixbuf);
@@ -208,10 +237,10 @@ void list_free(ListData *ld)
 	if (ld->row_overlay) gdk_pixbuf_unref(ld->row_overlay);
 	if (ld->row_overlay_center) gdk_pixbuf_unref(ld->row_overlay_center);
 	if (ld->divider_overlay) gdk_pixbuf_unref(ld->divider_overlay);
-	if (ld->text_overlay) gdk_pixbuf_unref(ld->text_overlay);
-	if (ld->text_selected_overlay) gdk_pixbuf_unref(ld->text_selected_overlay);
 	if (ld->flag_overlay) gdk_pixbuf_unref(ld->flag_overlay);
 
+	font_unref(ld->font);
+
 	g_free(ld->column_widths);
 	g_free(ld->column_flags);
 	g_free(ld->column_real_widths);
@@ -424,7 +453,7 @@ static void list_sync(ListData *ld)
 		}
 
 	/* vertical centering offsets */
-	ld->text_voff = MAX((ld->row_height - ld->char_height) / 2, 0);
+	ld->text_voff = MAX((ld->row_height - ld->font->char_height) / 2, 0);
 	ld->divider_voff = MAX((ld->row_height - ld->divider_height) / 2, 0);
 	ld->flag_voff = MAX((ld->row_height - ld->flag_height) / 2, 0);
 
@@ -558,34 +587,16 @@ static gint list_row_sync_all(ListData *ld, UIData *ui, const gchar *key, ListCa
  *-----------------------------
  */
 
-/* table to convert iso_8859 chars to similar ascii counterpart
- * only used in text_draw() (borrowed from ui2_text.c)
- */
-static const gchar iso_ascii[]=
-{
-	' ','|','c','L','c','Y','|','S','\"','c',' ','<','!','-','r','~',
-	'o',' ','2','3','\'','u','p','.',',','1',' ','>',' ',' ',' ','?',
-	'A','A','A','A','A','A','A','C','E','E','E','E','I','I','I','I',
-	'D','N','O','O','O','O','O','x','0','U','U','U','U','Y','P','B',
-	'a','a','a','a','a','a','a','c','e','e','e','e','i','i','i','i',
-	'o','n','o','o','o','o','o','/','o','u','u','u','u','y','p','y'
-};
-
 static void list_draw_text(ListData *ld, GdkPixbuf *pb, const gchar *text, gint x, gint y,
 			   gint w, gint right_justify, gint alpha)
 {
-	gint l;
 	gint p;
-	gint i;
 
 	if (!text) return;
 
-	l = strlen(text);
-
 	if (right_justify)
 		{
-		p = w;
-		for (i = 0; i < l; i++) p -= ld->char_width;
+		p = w - font_string_length(ld->font, text);
 		if (p < 0) p = 0;
 		}
 	else
@@ -593,46 +604,9 @@ static void list_draw_text(ListData *ld, GdkPixbuf *pb, const gchar *text, gint
 		p = 0;
 		}
 
-	i = 0;
-	while (i < l && p + ld->char_width <= w)
-		{
-		guint8 c;
-		gint px, py;
-
-		c = text[i];
-		if (ld->text_extended)
-			{
-			if(c >= 32 && c < 128)
-				c -= 32;
-			else if(c >= 160 && c < 256)
-				c -= 64;
-			else
-				c = 0;
-			}
-		else
-			{
-			if (c >= 32 && c < 128)
-				c -= 32;
-			else if (c >= 160 && c < 256)
-				{
-				/* translate to a limited set */
-				c = iso_ascii[c - 160];
-				c -= 32;
-				}
-			else
-				c = 0;
-			}
-		py = c / 32;
-		px = c - (py * 32);
-		px = px * ld->char_width;
-		py = py * ld->char_height;
-
-		pixbuf_copy_area_alpha(ld->text_overlay, px, py,
-				       pb, x + p, y,
-				       ld->char_width, ld->char_height, alpha);
-		i++;
-		p += ld->char_width;
-		}
+	font_draw(ld->font, text, 0, x + p, y, w - p, ld->font->char_height, 0,
+		  ld->text_r, ld->text_g, ld->text_b, ld->text_a,
+		  pb, ld->ui, alpha);
 }
 
 static void list_draw_cell(ListData *ld, GdkPixbuf *pb, gint x, gint y, gint row, gint column, gint divider)
@@ -682,23 +656,41 @@ static void list_draw_row(ListData *ld, GdkPixbuf *pb, UIData *ui, gint row, gin
 {
 	gint x, y;
 	gint i;
+	gint row_has_alpha;
+	gint pressed;
+	gint prelit;
 
 	x = ld->border_left;
 	y = row * ld->row_height + ld->border_top;
 
-	pixbuf_copy_area(ld->pixbuf, x, y,
-			 pb, ld->x + x, ld->y + y, ld->region_width, ld->row_height,
-			 FALSE);
-	list_draw_row_image(ld, pb, 0, x, y);
+	row_has_alpha = gdk_pixbuf_get_has_alpha(ld->row_overlay);
 
-	if (ld->row_has_press && row == ld->row_press - ld->row_start)
+	if (row_has_alpha)
+		{
+		pixbuf_copy_area(ld->pixbuf, x, y,
+				 pb, ld->x + x, ld->y + y, ld->region_width, ld->row_height,
+				 FALSE);
+		}
+
+	pressed = (ld->row_has_press && row == ld->row_press - ld->row_start);
+	prelit = (ld->row_has_prelight && row == ld->row_prelight - ld->row_start);
+
+	if (row_has_alpha || (!pressed && !prelit))
+		{
+		list_draw_row_image(ld, pb, 0, x, y);
+		}
+	if (pressed)
 		{
 		list_draw_row_image(ld, pb, ld->row_height, x, y);
 		}
+	if (prelit && (!row_has_alpha || slik_transparency_force))
+		{
+		list_draw_row_image(ld, pb, ld->row_height * (ld->row_has_press + 1), x, y);
+		}
 
 	x += ld->row_border_left;
 	i = 0;
-	while(i < ld->column_count && ld->column_real_widths[i] > 0)
+	while (i < ld->column_count && ld->column_real_widths[i] > 0)
 		{
 		gint divider;
 
@@ -710,7 +702,7 @@ static void list_draw_row(ListData *ld, GdkPixbuf *pb, UIData *ui, gint row, gin
 
 	x = ld->border_left;
 
-	if (ld->row_has_prelight && row == ld->row_prelight - ld->row_start)
+	if (prelit && (row_has_alpha && !slik_transparency_force))
 		{
 		list_draw_row_image(ld, pb, ld->row_height * (ld->row_has_press + 1), x, y);
 		}
@@ -859,6 +851,9 @@ static void list_row_scroll_by_row(ListData *ld, GdkPixbuf *pb, UIData *ui, cons
 		list_row_sync_all(ld, ui, key, NULL);
 		}
 
+	if (ld->focus_row < ld->row_start) ld->focus_row = ld->row_start;
+	if (ld->focus_row > ld->row_end) ld->focus_row = ld->row_end;
+
 	if (ld->row_prelight >= 0)
 		{
 		ld->row_prelight += ld->row_start - old_s;
@@ -1049,12 +1044,14 @@ static gint list_press(gpointer data, const gchar *key, gint x, gint y, GdkPixbu
 		guint32 t;
 		gint row;
 
+		row = list_row_find_proximity(ld, x, y);
+		if (row == -1) return FALSE;
+
 		ld->pressed = TRUE;
 		ld->press_x = x;
 		ld->press_y = y;
 		ld->in_drag = FALSE;
 
-		row = list_row_find_proximity(ld, x, y);
 		t = gdk_time_get();
 
 		rd = g_list_nth_data(ld->row_list, row - ld->row_start);
@@ -1121,13 +1118,13 @@ static void list_release(gpointer data, const gchar *key, gint x, gint y, GdkPix
 	if (list_test_proximity(ld, x, y))
 		{
 		gint row;
-		row = list_row_find_proximity(ld, x, y);
 
+		row = list_row_find_proximity(ld, x, y);
 		if (row != ld->row_press)
 			{
 			list_row_press_set(ld, pb, ui, -1);
 			}
-		else
+		else if (row >= 0)
 			{
 			ListCallbackData *cd;
 
@@ -1156,8 +1153,11 @@ static void list_back_set(gpointer data, GdkPixbuf *pb)
 
 	list_sync(ld);
 
-	pixbuf_copy_area(pb, ld->x, ld->y,
-			 ld->pixbuf, 0, 0, ld->width, ld->height, TRUE);
+	if (!ld->overlay || gdk_pixbuf_get_has_alpha(ld->overlay))
+		{
+		pixbuf_copy_area(pb, ld->x, ld->y,
+				 ld->pixbuf, 0, 0, ld->width, ld->height, TRUE);
+		}
 
 	pixbuf_copy_fill_border_alpha(ld->overlay, ld->pixbuf,
 				      ld->border_left, FALSE,
@@ -1174,6 +1174,8 @@ static gint list_key_event_cb(gpointer widget, const gchar *key, GdkEventKey *ev
 	gint new_row;
 	gint old_row;
 
+	if (event->state & GDK_CONTROL_MASK) return FALSE;
+
 	old_row = new_row = ld->focus_row;
 
 	switch (event->keyval)
@@ -1346,11 +1348,30 @@ static void list_set_coord(gpointer widget, gint x, gint y)
 static void list_set_size(gpointer widget, gint dev_w, gint dev_h)
 {
 	ListData *ld = widget;
+	UIData *ui;
+	WidgetData *wd;
 
 	if (!ld->sizeable) return;
 
-	ld->width = MAX(ld->width + dev_w, ld->border_left + ld->border_right + ld->row_border_left + ld->row_border_right + 4);
-	ld->height = MAX(ld->height + dev_h, ld->border_top + ld->border_bottom + ld->row_height);
+	ui = skin_get_ui(ld->skin);
+	if (ui)
+		{
+		wd = ui_widget_get_by_widget(ui, ld);
+		}
+	else
+		{
+		wd = NULL;
+		}
+
+	if (!wd || !wd->anchor_right)
+		{
+		ld->width = MAX(ld->width + dev_w,
+			       	ld->border_left + ld->border_right + ld->row_border_left + ld->row_border_right + 4);
+		}
+	if (!wd || !wd->anchor_bottom)
+		{
+		ld->height = MAX(ld->height + dev_h, ld->border_top + ld->border_bottom + ld->row_height);
+		}
 
 	list_sync(ld);
 }
@@ -1374,6 +1395,8 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	gchar *divider_filename;
 	gchar *flag_filename;
 	gchar *text_filename;
+	const gchar *font_desc;
+	gint r, g, b, a;
 	gint flag_sections;
 	gint flag_column;
 	gint row_prelight;
@@ -1405,7 +1428,8 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	filename = key_list_read_path(list, "image", skin_dir);
 	row_filename = key_list_read_path(list, "row_image", skin_dir);
 	text_filename = key_list_read_path(list, "text_image", skin_dir);
-	if (!filename || !row_filename || !text_filename)
+	font_desc = key_list_read_chars(list, "text_font", NULL);
+	if (!filename || !row_filename || (!text_filename && !font_desc) )
 		{
 		g_free(filename);
 		g_free(row_filename);
@@ -1430,6 +1454,13 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 
 	text_extended = key_list_read_bool(list, "text_extended");
 
+	if (!key_list_read_int(list, "text_red", &r)) r = 0;
+	if (!key_list_read_int(list, "text_green", &g)) g = 0;
+	if (!key_list_read_int(list, "text_blue", &b)) b = 0;
+	if (!key_list_read_int(list, "text_alpha", &a)) a = 255;
+
+	util_color(&r, &g, &b, NULL);
+
 	ld = list_new(gdk_pixbuf_new_from_file(filename), x, y, w, h, sizeable, columns,
 		      border_top, border_right, border_bottom, border_left, center_stretch);
 	if (ld)
@@ -1439,7 +1470,16 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 		list_image_row(ld, gdk_pixbuf_new_from_file(row_filename), row_press, row_prelight,
 			       row_border_left, row_border_right, row_stretch,
 			       divider_filename ? gdk_pixbuf_new_from_file(divider_filename) : NULL);
-		list_image_text(ld, gdk_pixbuf_new_from_file(text_filename), text_extended);
+
+		if (text_filename)
+			{
+			list_set_font(ld, NULL, gdk_pixbuf_new_from_file(text_filename), text_extended, r, g, b, a);
+			}
+		else
+			{
+			list_set_font(ld, font_desc, NULL, FALSE, r, g, b, a);
+			}
+
 		if (flag_filename) list_image_row_flag(ld, gdk_pixbuf_new_from_file(flag_filename), flag_sections, flag_column);
 
 		list_set_column_justify(ld, columns_right_justify);
@@ -1473,8 +1513,11 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 			list_set_column_attributes(ld, i, length, flags, key);
 			}
 
-		if (!ld->row_overlay || !ld->text_overlay)
+		if (!ld->row_overlay || !ld->font)
 			{
+			if (!ld->font) printf("list warning: failed to load font.\n");
+			if (!ld->row_overlay) printf("list warning: failed to load row image.\n");
+
 			list_free(ld);
 			ld = NULL;
 			}
@@ -1511,6 +1554,12 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 
 WidgetData *list_register(SkinData *skin, ListData *ld, const gchar *key, const gchar *text_id)
 {
+	if (!ld || !ld->font)
+		{
+		printf("warning: attempt to register list \"%s\" will NULL font.\n", key);
+		}
+	if (ld) ld->skin = skin;
+	
 	return skin_register_widget(skin, key, text_id, type_id, ld);
 }
 
@@ -1814,11 +1863,24 @@ static gfloat list_scroll_slider_status(SliderData *slider, const gchar *key, gp
 	return list_scroll_position(ld);
 }
 
+static gint list_scroll_idle_cb(gpointer data)
+{
+	ListData *ld = data;
+
+	if (ld->scroll_idle_id == -1) return FALSE;
+
+	list_row_scroll(ld, skin_get_pixbuf(ld->ui->skin), ld->ui, ld->wd->key, ld->scroll_idle_value);
+	
+	ld->scroll_idle_id = -1;
+	return FALSE;
+}
+
 static void list_scroll_slider_drag(SliderData *slider, const gchar *key, gfloat value, gpointer data)
 {
 	ListData *ld = data;
 
-	list_row_scroll(ld, skin_get_pixbuf(ld->ui->skin), ld->ui, ld->wd->key, value);
+	ld->scroll_idle_value = value;
+	if (ld->scroll_idle_id == -1) ld->scroll_idle_id = gtk_idle_add(list_scroll_idle_cb, ld);
 }
 
 static void list_init(gpointer widget, const gchar *key, UIData *ui)
