@@ -13,6 +13,9 @@
 #define UI2_LIST_H
 
 
+#include "ui2_text.h"
+
+
 /*
  * This widget is only a view, the data is requested only when display is necessary
  */
@@ -61,11 +64,11 @@ struct _ListData
 	gint divider_width;
 	gint divider_height;
 
-	GdkPixbuf *text_overlay;
-	GdkPixbuf *text_selected_overlay;
-	gint text_extended;
-	gint char_width;
-	gint char_height;
+	FontData *font;
+	guint8 text_r;
+	guint8 text_g;
+	guint8 text_b;
+	guint8 text_a;
 
 	GdkPixbuf *flag_overlay;
 	gint flag_width;
@@ -112,6 +115,10 @@ struct _ListData
 	guint32 click_time;	/* used to check for a double click ? */
 	gint scroll_count;	/* for delayed scroll speedup after 8 rows */
 
+	/* delayed scrolling (from slider) */
+	gint scroll_idle_id;
+	gfloat scroll_idle_value;
+
 	/* mouse stuff */
 	gint pressed;
 	gint press_x;
@@ -134,7 +141,8 @@ ListData *list_new(GdkPixbuf *pb, gint x, gint y, gint w, gint h, gint sizeable,
 void list_image_row(ListData *ld, GdkPixbuf *pb, gint has_press, gint has_prelight,
                     gint border_left, gint border_right, gint stretch, GdkPixbuf *divider);
 void list_image_row_flag(ListData *ld, GdkPixbuf *pb, gint sections, gint column);
-void list_image_text(ListData *ld, GdkPixbuf *pb, gint extended);
+void list_set_font(ListData *ld, const gchar *description, GdkPixbuf *pb, gint extended,
+		   guint8 r, guint8 g, guint8 b, guint8 a);
 
 void list_set_column_attributes(ListData *ld, gint column, gint length, ListColumnFlags flags, const gchar *key);
 void list_set_column_justify(ListData *ld, gint justify_right);
