@@ -54,6 +54,12 @@ struct _ListDetail
 	GtkWidget *text_image_entry;
 	GtkWidget *text_extended_button;
 
+	GtkWidget *text_font_entry;
+	GtkWidget *text_font_r;
+	GtkWidget *text_font_g;
+	GtkWidget *text_font_b;
+	GtkWidget *text_font_a;
+
 	GtkWidget *flag_image_entry;
 	GtkWidget *flag_sections_spin;
 	GtkWidget *flag_column_spin;
@@ -98,6 +104,12 @@ struct _ListListData
 	gchar *text_image;
 	gint text_extended;
 
+	gchar *text_font;
+	gint text_r;
+	gint text_g;
+	gint text_b;
+	gint text_a;
+
 	gchar *flag_image;
 	gint flag_sections;
 	gint flag_column;
@@ -160,8 +172,16 @@ static void list_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 					 dir, ld->overlay, "list_", wd->key);
 	row_image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "row_image"),
 					     dir, ld->row_overlay, "list_row_", wd->key);
-	text_image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "text_image"),
-					     dir, ld->text_overlay, "list_text_", wd->key);
+	if (ld->font->overlay)
+		{
+		text_image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "text_image"),
+						     dir, ld->font->overlay, "list_text_", wd->key);
+		}
+	else
+		{
+		text_image = NULL;
+		}
+
 	if (ld->divider_overlay)
 		{
 		divider_image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "divider_image"),
@@ -216,8 +236,19 @@ static void list_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 	ui_edit_write_key_int(f, "row_border_right", ld->row_border_right);
 	ui_edit_write_key_bool(f, "row_stretch", ld->row_stretch);
 
-	ui_edit_write_key_char(f, "text_image", text_image);
-	ui_edit_write_key_bool(f, "text_extended", ld->text_extended);
+	if (text_image)
+		{
+		ui_edit_write_key_char(f, "text_image", text_image);
+		ui_edit_write_key_bool(f, "text_extended", ld->font->extended);
+		}
+	if (ld->font->font_description)
+		{
+		ui_edit_write_key_char(f, "text_font", ld->font->font_description);
+		ui_edit_write_key_int(f, "text_red", ld->text_r);
+		ui_edit_write_key_int(f, "text_green", ld->text_g);
+		ui_edit_write_key_int(f, "text_blue", ld->text_b);
+		ui_edit_write_key_int(f, "text_alpha", ld->text_a);
+		}
 
 	if (divider_image) ui_edit_write_key_char(f, "divider_image", divider_image);
 	if (flag_image)
@@ -301,7 +332,13 @@ static gpointer list_edit_read(UIData *ui, WidgetData *wd, GList *list)
 	ll->divider_image = g_strdup(ui_widget_get_data(wd, "divider_image"));
 
 	ll->text_image = g_strdup(ui_widget_get_data(wd, "text_image"));
-	ll->text_extended = ld->text_extended;
+	ll->text_extended = ld->font->extended;
+
+	ll->text_font = g_strdup(ld->font->font_description);
+	ll->text_r = ld->text_r;
+	ll->text_g = ld->text_g;
+	ll->text_b = ld->text_b;
+	ll->text_a = ld->text_a;
 
 	ll->flag_image = g_strdup(ui_widget_get_data(wd, "flag_image"));
 	ll->flag_sections = ld->flag_sections;
@@ -339,6 +376,7 @@ static void list_edit_free(gpointer data)
 	g_free(ll->row_image);
 	g_free(ll->divider_image);
 	g_free(ll->text_image);
+	g_free(ll->text_font);
 	g_free(ll->flag_image);
 	g_free(ll->column_widths);
 	g_free(ll->column_flags);
@@ -358,6 +396,7 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	GtkWidget *page;
 	GtkWidget *label;
 	GtkWidget *hbox;
+	GtkWidget *hbox2;
 	GtkWidget *vbox2;
 	GtkWidget *scrolled;
 	GtkWidget *pixmap;
@@ -425,12 +464,20 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	gtk_container_set_border_width(GTK_CONTAINER(page), 5);
 
 	hbox = ui_edit_vframe_new(page, FALSE, NULL);
+	dt->text_font_entry = ui_edit_font_entry_new(hbox, _("Font:"));
 	dt->text_image_entry = ui_edit_path_entry_new(hbox, _("Image:"), "SLIK_list_text_image");
 	pixmap = ui_edit_pixmap_new(hbox);
 	ui_edit_path_entry_connect_pixmap(dt->text_image_entry, pixmap);
 
 	dt->text_extended_button = ui_edit_toggle_new(hbox, _("Extended"));
 
+	hbox2 = ui_edit_frame_new(hbox, TRUE, _("Color:"));
+	dt->text_font_r = ui_edit_spin_new(hbox2, _("Red:"), 0, 255, NULL);
+	dt->text_font_g = ui_edit_spin_new(hbox2, _("Green:"), 0, 255, NULL);
+	dt->text_font_b = ui_edit_spin_new(hbox2, _("Blue:"), 0, 255, NULL);
+
+	dt->text_font_a = ui_edit_spin_new(hbox, _("Alpha:"), 0, 255, NULL);
+
 	label = gtk_label_new(_("Text"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page, label);
 	gtk_widget_show(page);
@@ -562,7 +609,14 @@ static void list_edit_props_sync(ListDetail *dt)
 	ui_edit_entry_set(dt->divider_image_entry, ui_widget_get_data(wd, "divider_image"));
 
 	ui_edit_entry_set(dt->text_image_entry, ui_widget_get_data(wd, "text_image"));
-	ui_edit_toggle_set(dt->text_extended_button, ld->text_extended);
+	ui_edit_toggle_set(dt->text_extended_button, ld->font->extended);
+
+	ui_edit_entry_set(dt->text_font_entry, ld->font->font_description);
+
+	ui_edit_spin_set_blocking(dt->text_font_r, ld->text_r, dt);
+	ui_edit_spin_set_blocking(dt->text_font_g, ld->text_g, dt);
+	ui_edit_spin_set_blocking(dt->text_font_b, ld->text_b, dt);
+	ui_edit_spin_set_blocking(dt->text_font_a, ld->text_a, dt);
 
 	ui_edit_entry_set(dt->flag_image_entry, ui_widget_get_data(wd, "flag_image"));
 	ui_edit_spin_set(dt->flag_sections_spin, ld->flag_sections);
@@ -909,6 +963,18 @@ static gint list_props_column_clist_cb(GtkWidget *widget, GdkEventButton *event,
 	return FALSE;
 }
 
+static void list_props_text_color_cb(GtkAdjustment *adj, gpointer data)
+{
+	ListDetail *dt = data;
+
+	dt->ld->text_r = ui_edit_spin_get(dt->text_font_r);
+	dt->ld->text_g = ui_edit_spin_get(dt->text_font_g);
+	dt->ld->text_b = ui_edit_spin_get(dt->text_font_b);
+	dt->ld->text_a = ui_edit_spin_get(dt->text_font_a);
+
+	if (!dt->ld->font->overlay) ui_edit_widget_resync(dt->ui, dt->wd, TRUE, 0, 0);
+}
+
 static void list_props_flag_column_cb(GtkAdjustment *adj, gpointer data)
 {
 	ListDetail *dt = data;
@@ -970,8 +1036,15 @@ static void list_props_signals(ListDetail *dt)
 
 	ui_edit_frame_sensitive(dt->divider_image_entry, FALSE, FALSE);
 
-	ui_edit_frame_sensitive(dt->text_image_entry, FALSE, FALSE);
-	ui_edit_frame_sensitive(dt->text_extended_button, FALSE, TRUE);
+	ui_edit_frame_sensitive(dt->text_image_entry, FALSE, TRUE);
+	gtk_widget_set_sensitive(dt->text_extended_button, FALSE);
+
+	ui_edit_frame_sensitive(dt->text_font_entry, FALSE, TRUE);
+
+	list_props_connect_spin(dt->text_font_r, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_g, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_b, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_a, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
 
 	ui_edit_frame_sensitive(dt->flag_image_entry, FALSE, FALSE);
 	ui_edit_frame_sensitive(dt->flag_sections_spin, FALSE, TRUE);
@@ -1018,6 +1091,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 	const gchar *image;
 	const gchar *row_image;
 	const gchar *text_image;
+	const gchar *font_desc;
 	const gchar *divider_image;
 	const gchar *flag_image;
 	ListData *ld;
@@ -1029,20 +1103,29 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 	image = ui_edit_entry_get(dt->image_entry);
 	row_image = ui_edit_entry_get(dt->row_image_entry);
 	text_image = ui_edit_entry_get(dt->text_image_entry);
+	font_desc = ui_edit_entry_get(dt->text_font_entry);
 	divider_image = ui_edit_entry_get(dt->divider_image_entry);
 	flag_image = ui_edit_entry_get(dt->flag_image_entry);
 
 	if (!key || !image || !isfile(image))
 		{
 		warning_dialog(_("List error"), _("List must contain a key and valid image."));
+		return;
 		}
 	if (!row_image || !isfile(row_image))
 		{
 		warning_dialog(_("List error"), _("Invalid or missing row image."));
+		return;
 		}
-	if (!text_image || !isfile(text_image))
+	if (text_image && !isfile(text_image))
 		{
 		warning_dialog(_("List error"), _("Invalid or missing text image."));
+		return;
+		}
+	else if (!font_desc && !text_image)
+		{
+		warning_dialog(_("List error"), _("Must specify valid font description or image."));
+		return;
 		}
 
 	ld = list_new(gdk_pixbuf_new_from_file(image),
@@ -1057,6 +1140,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 		gint n;
 		GList *work;
 		WidgetData *wd;
+		guint8 r, g, b, a;
 
 		if (divider_image) pb = gdk_pixbuf_new_from_file(divider_image);
 
@@ -1067,8 +1151,27 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 			       ui_edit_spin_get(dt->row_border_right_spin),
 			       ui_edit_toggle_get(dt->row_stretch_button), pb);
 
-		list_image_text(ld, gdk_pixbuf_new_from_file(text_image),
-				ui_edit_toggle_get(dt->text_extended_button));
+		r = ui_edit_spin_get(dt->text_font_r);
+		g = ui_edit_spin_get(dt->text_font_g);
+		b = ui_edit_spin_get(dt->text_font_b);
+		a = ui_edit_spin_get(dt->text_font_a);
+
+		if (font_desc)
+			{
+			list_set_font(ld, font_desc, NULL, FALSE, r, g, b, a);
+			}
+		else if (text_image)
+			{
+			list_set_font(ld, NULL, gdk_pixbuf_new_from_file(text_image), 
+				      ui_edit_toggle_get(dt->text_extended_button), r, g, b, a);
+			}
+
+		if (!ld->font)
+			{
+			warning_dialog(_("List error"), _("Failed to initialize font with specified parameters."));
+			list_free(ld);
+			return;
+			}
 
 		list_set_column_justify(ld, ui_edit_toggle_get(dt->columns_right_toggle));
 
@@ -1090,7 +1193,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 
 		wd = list_register(pd->ed->ui->skin, ld, key, text_id);
 		ui_widget_set_data(wd, "row_image", row_image);
-		ui_widget_set_data(wd, "text_image", text_image);
+		if (!font_desc) ui_widget_set_data(wd, "text_image", text_image);
 		ui_widget_set_data(wd, "divider_image", divider_image);
 		ui_widget_set_data(wd, "flag_image", flag_image);
 		ui_edit_widget_add_finish(pd->ed, wd, image, ui_edit_entry_get(pd->data_entry));
@@ -1215,6 +1318,13 @@ static void list_edit_page_sync(ListPage *pd, ListListData *ll)
 	ui_edit_entry_set(dt->text_image_entry, ll->text_image);
 	ui_edit_toggle_set(dt->text_extended_button, ll->text_extended);
 
+	ui_edit_entry_set(dt->text_font_entry, ll->text_font);
+
+	ui_edit_spin_set(dt->text_font_r, ll->text_r);
+	ui_edit_spin_set(dt->text_font_g, ll->text_g);
+	ui_edit_spin_set(dt->text_font_b, ll->text_b);
+	ui_edit_spin_set(dt->text_font_a, ll->text_a);
+
 	ui_edit_entry_set(dt->flag_image_entry, ll->flag_image);
 	ui_edit_spin_set(dt->flag_sections_spin, ll->flag_sections);
 
@@ -1280,6 +1390,22 @@ static void list_edit_column_count_cb(GtkObject *object, gpointer data)
 	list_edit_page_clist_sync(pd);
 }
 
+static void list_edit_font_change_cb(GtkWidget *w, gpointer data)
+{
+	ListPage *pd = data;
+	ListDetail *dt;
+	gint sensitive;
+
+	dt = (ListDetail *)pd;
+
+	sensitive = (strlen(gtk_entry_get_text(GTK_ENTRY(dt->text_font_entry))) == 0);
+
+	ui_edit_frame_sensitive(dt->text_image_entry, sensitive, TRUE);
+	gtk_widget_set_sensitive(dt->text_extended_button, sensitive);
+
+	ui_edit_frame_sensitive(dt->text_font_r, !sensitive, FALSE);
+	ui_edit_frame_sensitive(dt->text_font_a, !sensitive, TRUE);
+}
 
 static void list_edit_page_destroy_cb(GtkWidget *widget, gpointer data)
 {
@@ -1320,6 +1446,15 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 
 	list_details_pack(dt, vbox, TRUE);
 
+	gtk_signal_connect(GTK_OBJECT(dt->text_font_entry), "changed",
+			   GTK_SIGNAL_FUNC(list_edit_font_change_cb), pd);
+
+	ui_edit_entry_set(dt->text_font_entry, SLIK_DEFAULT_X_FONT);
+	ui_edit_spin_set(dt->text_font_r, 0);
+	ui_edit_spin_set(dt->text_font_g, 0);
+	ui_edit_spin_set(dt->text_font_b, 0);
+	ui_edit_spin_set(dt->text_font_a, 255);
+
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(dt->column_count_spin));
         gtk_signal_connect(GTK_OBJECT(adj), "value_changed",
 			   GTK_SIGNAL_FUNC(list_edit_column_count_cb), pd);
@@ -1373,4 +1508,3 @@ void list_type_init_edit(WidgetObjectData *od)
 	od->func_edit_page_new = list_edit_page_new;
 	od->func_edit_page_add = list_edit_page_add;
 }
-
