@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2002 John Ellis
+ * (C) 2003 John Ellis
  *
  * Author: John Ellis
  *
@@ -121,6 +121,7 @@ static gint ui_mode_unique(UIData *ui, const gchar *mode_key)
 
 	if (strcmp(mode_key, "skindata") == 0) return FALSE;
 	if (ui->skin_mode_key && strcmp(ui->skin_mode_key, mode_key) == 0) return FALSE;
+	if (ui->key && strcmp(ui->key, mode_key) == 0) return FALSE;
 
 	work = ui->children;
 	while (work)
@@ -130,7 +131,7 @@ static gint ui_mode_unique(UIData *ui, const gchar *mode_key)
 		child = work->data;
 		work = work->next;
 
-		if (child->skin_mode_key && strcmp(child->skin_mode_key, mode_key) == 0) return FALSE;
+		if (child->key && strcmp(child->key, mode_key) == 0) return FALSE;
 		}
 
 	return TRUE;
@@ -190,6 +191,9 @@ static void ui_skin_expand_click_cb(ButtonData *button, const gchar *key, gpoint
 
 		if (skin->width == skin->width_def && skin->height == skin->height_def)
 			{
+			util_size(&w);
+			util_size(&h);
+
 			/* do the expand (can be negative too) */
 			skin_resize(ui, skin->width + w, skin->height + h);
 			state = TRUE;
@@ -204,13 +208,79 @@ static void ui_skin_expand_click_cb(ButtonData *button, const gchar *key, gpoint
 		}
 }
 
+UIData *ui_spawn_child(UIData *parent, const gchar *key, const gchar *title, const gchar *mode_key)
+{
+	UIData *child;
+	SkinData *skin;
+
+	if (!key) return NULL;
+
+	if (parent->parent) parent = parent->parent;
+
+	if (debug_mode) printf("ui2_main.c: opening skin \"%s\"for addition as \"%s\"\n", (mode_key) ? mode_key : "default", key);
+
+	if (parent->skin_path)
+		{
+		gchar *datafile;
+
+		datafile = g_strconcat(parent->skin_path, "/", (mode_key) ? mode_key : "skindata", NULL);
+		skin = skin_parse(parent->skin_path, datafile, FALSE);
+		g_free(datafile);
+		}
+	else
+		{
+		if (parent->skin_func)
+			{
+			skin = parent->skin_func(parent, mode_key, parent->skin_data);
+			}
+		else
+			{
+			skin = NULL;
+			}
+		}
+
+	if (!skin)
+		{
+		printf("ui2_main.c: failed to open skin \"%s\"for spawned window\n", mode_key);
+		return NULL;
+		}
+
+	child = ui_new(parent->class, key, parent->decorations, parent->class);
+	ui_title_set(child, title);
+	child->allow_move = parent->allow_move;
+
+	/* copy a few things from parent, it is up to the application to determine if
+	 * the UI in the callback(s) is the parent.
+	 */
+	child->click_func = parent->click_func;
+	child->click_data = parent->click_data;
+
+	child->skin_func = parent->skin_func;
+	child->skin_data = parent->skin_data;
+
+	child->back_func = parent->back_func;
+	child->back_data = parent->back_data;
+
+	child->new_window_func = parent->new_window_func;
+	child->new_window_data = parent->new_window_data;
+
+	ui_group_set_child(parent, child);
+
+	ui_skin_set(child, skin, parent->skin_path, mode_key);
+
+	if (parent->new_window_func)
+		{
+		parent->new_window_func(child, child->key, parent->new_window_data);
+		}
+
+	return child;
+}
+
 static void ui_skin_open_click_cb(ButtonData *button, const gchar *key, gpointer data)
 {
 	UIData *ui = data;
-	const gchar *mode_key;
-	gchar *datafile;
 	UIData *child;
-	SkinData *skin;
+	const gchar *mode_key;
 
 	mode_key = ui_widget_get_data_by_widget(ui, button);
 
@@ -224,37 +294,11 @@ static void ui_skin_open_click_cb(ButtonData *button, const gchar *key, gpointer
 
 	if (debug_mode) printf("ui2_main.c: opening skin \"%s\"for addition\n", mode_key);
 
-	datafile = g_strconcat(ui->skin_path, "/", (mode_key) ? mode_key : "skindata", NULL);
-	skin = skin_parse(ui->skin_path, datafile, FALSE);
-	g_free(datafile);
-
-	if (!skin)
+	child = ui_spawn_child(ui, mode_key, NULL, mode_key);
+	if (child)
 		{
-		printf("ui2_main.c: failed to open skin \"%s\"for new window\n", mode_key);
-		return;
+		gtk_widget_show(child->window);
 		}
-
-	if (ui->parent) ui = ui->parent;
-
-	child = ui_new(ui->class, mode_key, ui->decorations, ui->class);
-	child->allow_move = ui->allow_move;
-
-	/* copy a few things from parent, it is up to the application to determine if
-	 * the UI in the callback is the parent.
-	 */
-	child->click_func = ui->click_func;
-	child->click_data = ui->click_data;
-
-	ui_group_set_child(ui, child);
-
-	ui_skin_set(child, skin, ui->skin_path, mode_key);
-
-	if (ui->new_window_func)
-		{
-		ui->new_window_func(child, child->key, ui->new_window_data);
-		}
-
-	gtk_widget_show(child->window);
 }
 
 static void ui_skin_close_click_cb(ButtonData *button, const gchar *key, gpointer data)
@@ -339,6 +383,21 @@ void ui_free(UIData *ui)
 {
 	if (!ui) return;
 
+	if (!ui->destroyed)
+		{
+		printf("warning: free called for ui \"%s\" not marked as destroyed\n", ui->key);
+		}
+
+	/* close children */
+	while (ui->children)
+		{
+		UIData *child = ui->children->data;
+		ui_close(child);
+		}
+
+	/* if child, break from parent */
+	ui_group_unset_child(ui);
+
 	slik_ui_list = g_list_remove(slik_ui_list, ui);
 
 	if (ui->root_win_idle != -1) gtk_idle_remove(ui->root_win_idle);
@@ -399,6 +458,7 @@ static void ui_destroy_cb(GtkWidget *widget, gpointer data)
 
 	if (debug_mode) printf("UI destroyed \"%s\"\n", ui->key);
 
+	ui->destroyed = TRUE;
 	ui_free(ui);
 }
 
@@ -416,6 +476,7 @@ static UIData *ui_real_new(const gchar *class, const gchar *key,
 	ui->class = g_strdup((class) ? class : "SLIK");
 	ui->key = g_strdup(key);
 	ui->allow_move = TRUE;
+	ui->focus_enable = FALSE;
 
 	ui->parent = NULL;
 	ui->children = NULL;
@@ -444,7 +505,10 @@ static UIData *ui_real_new(const gchar *class, const gchar *key,
 
 	gtk_widget_realize(ui->display);
 
-	if (type != GTK_WINDOW_POPUP && !ui->decorations) gdk_window_set_decorations(ui->window->window, 0);
+	if (type != GTK_WINDOW_POPUP && !ui->decorations)
+		{
+		gdk_window_set_decorations(ui->window->window, 0);
+		}
 
 	/* add the default reserved keys */
 	ui_add_reserved(ui);
@@ -477,6 +541,7 @@ UIData *ui_new_into_container(const gchar *class, const gchar *key, GtkWidget *w
 	ui->class = g_strdup((class) ? class : "SLIK");
 	ui->key = g_strdup(key);
 	ui->allow_move = FALSE;
+	ui->focus_enable = FALSE;
 
 	ui->parent = NULL;
 	ui->children = NULL;
@@ -522,8 +587,6 @@ static gint ui_close_cb(gpointer data)
 
 void ui_close(UIData *ui)
 {
-	GList *work;
-
 	if (!ui || ui->destroyed) return;
 
 	/* This may be called in the middle of a widget event (like a button press handler),
@@ -534,26 +597,18 @@ void ui_close(UIData *ui)
 	ui->destroyed = TRUE;
 	if (ui->window && GTK_WIDGET_VISIBLE(ui->window)) gtk_widget_hide(ui->window);
 
-	/* close children */
-	work = ui->children;
-	while (work)
+	/* close children.
+	 * this may be duplicating effort in ui free,
+	 * but has the benefit immediately hiding the windows.
+	 */
+	while (ui->children)
 		{
-		UIData *child = work->data;
-		work = work->next;
-
+		UIData *child = ui->children->data;
 		ui_close(child);
 		}
 
 	/* if a child, break from parent */
-	if (ui->parent)
-		{
-		UIData *parent;
-
-		parent = ui->parent;
-
-		parent->children = g_list_remove(parent->children, ui);
-		ui->parent = NULL;
-		}
+	ui_group_unset_child(ui);
 
 	gtk_idle_add(ui_close_cb, ui);
 }
@@ -862,6 +917,11 @@ void ui_moveable_set(UIData *ui, gint moveable)
 	ui->allow_move = moveable;
 }
 
+void ui_focus_set(UIData *ui, gint enable)
+{
+	ui->focus_enable = enable;
+}
+
 void ui_skin_set(UIData *ui, SkinData *skin, const gchar *path, const gchar *mode_key)
 {
 	gchar *tmp;
@@ -1141,8 +1201,28 @@ void ui_group_set_child(UIData *parent, UIData *child)
 
 	if (child->parent) return;
 
+	/* children are linear,
+	 * that is one parent and the rest are children of that parent (no complex trees!)
+	 */
+	if (parent->parent) parent = parent->parent;
+
 	child->parent = parent;
 	parent->children = g_list_append(parent->children, child);
+
+	if (debug_mode) printf("setting %s as a child of %s\n", child->skin_mode_key, parent->skin_mode_key);
+}
+
+void ui_group_unset_child(UIData *child)
+{
+	UIData *parent;
+	
+	if (!child || !child->parent) return;
+
+	parent = child->parent;
+	parent->children = g_list_remove(parent->children, child);
+	child->parent = NULL;
+
+	if (debug_mode) printf("removed %s as a child of %s\n", child->skin_mode_key, parent->skin_mode_key);
 }
 
 UIData *ui_group_get_parent(UIData *ui)
@@ -1236,7 +1316,7 @@ static void ui_slik_about(void)
 	gtk_box_pack_start(GTK_BOX(vbox), pixmap, FALSE, FALSE, 0);
 	gtk_widget_show(pixmap);
 
-	buf = g_strdup_printf(_("SLIK\nSimpLIstic sKin interface\nversion %s\nCopyright (c) 2002 by John Ellis\nhttp://gqmpeg.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), SLIK_VERSION);
+	buf = g_strdup_printf(_("SLIK\nSimpLIstic sKin interface\nversion %s\nCopyright (c) 2003 by John Ellis\nhttp://gqmpeg.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), SLIK_VERSION);
 	label = gtk_label_new(buf);
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
