@@ -20,10 +20,13 @@ void ui_free(UIData *ui);
 UIData *ui_new(const gchar *class, const gchar *key, gint decorations, const gchar *title);
 void ui_title_set(UIData *ui, const gchar *text);
 void ui_moveable_set(UIData *ui, gint moveable);
+void ui_focus_set(UIData *ui, gint enable);
 
 UIData *ui_new_dialog(const gchar *class, const gchar *subclass, gint decorations, const gchar *title);
 UIData *ui_new_into_container(const gchar *class, const gchar *key, GtkWidget *widget);
 
+UIData *ui_spawn_child(UIData *parent, const gchar *key, const gchar *title, const gchar *mode_key);
+
 void ui_close(UIData *ui);
 
 void ui_set_mouse_callback(UIData *ui, void (*func)(UIData *ui, gint button, guint32 time, gpointer data), gpointer data);
@@ -68,6 +71,7 @@ void ui_iconify(UIData *ui);
 UIData *ui_find_by_key(const gchar *key);
 
 void ui_group_set_child(UIData *parent, UIData *child);
+void ui_group_unset_child(UIData *child);
 UIData *ui_group_get_parent(UIData *ui);
 
 const char **ui_slik_logo(void);
