@@ -296,27 +296,28 @@ static void ui_menu_calc_size(MenuItemData *mi)
 		ListData *ld;
 		GList *work;
 		gint rows;
-		gint chars;
+		gint string_width;
 
 		ld = wd->widget;
 
 		rows = MAX(0, g_list_length(mi->children) - 1);
+		string_width = 32;
 
-		chars = 8;
 		work = mi->children;
 		while (work)
 			{
 			MenuItemData *mi;
+			gint cw;
 
 			mi = work->data;
 			work = work->next;
 
-			chars = MAX(chars, strlen(mi->text));
+			cw = font_string_length(ld->font, mi->text);
+			if (cw > string_width) string_width = cw;
 			}
-		chars -= 8;
 
 		h += ld->row_height * rows;
-		w += chars * ld->char_width;
+		w += string_width;
 
 		mi->y -= ld->y + ld->border_top;
 		}
@@ -728,6 +729,8 @@ static UIData *ui_menu_submenu_new(MenuItemData *mi, const gchar *class, const g
 	ui->window = window;
 	mi->ui = ui;
 
+	ui_focus_set(ui, TRUE);
+
 #if 0
 	gtk_signal_connect(GTK_OBJECT(ui->display), "button_press_event",
 			   GTK_SIGNAL_FUNC(ui_menu_press_cb), mi);
@@ -748,8 +751,12 @@ static UIData *ui_menu_submenu_new(MenuItemData *mi, const gchar *class, const g
 
 	if (mi->md->ui)
 		{
+		/* sub windows inheret parent functions */
 		ui->skin_func = mi->md->ui->skin_func;
 		ui->skin_data = mi->md->ui->skin_data;
+
+		/* and the ui group */
+		ui_group_set_child(mi->md->ui, ui);
 		}
 	ui_set_back_callback(ui, ui_menu_back_cb, mi);
 
