@@ -39,6 +39,8 @@ typedef struct _FontDetail FontDetail;
 struct _FontDetail
 {
 	GtkWidget *extended_button;
+
+	GtkWidget *font_entry;
 };
 
 typedef struct _FontListData FontListData;
@@ -50,6 +52,8 @@ struct _FontListData
 
 	gchar *image;
 	gint extended;
+
+	gchar *description;
 };
 
 static GdkPixbuf *font_get_pixbuf(gpointer widget)
@@ -62,19 +66,26 @@ static GdkPixbuf *font_get_pixbuf(gpointer widget)
 static void font_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar *dir)
 {
 	FontData *font = wd->widget;
-	gchar *image;
-
-	image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "image"),
-					 dir, font->overlay, "font_", wd->key);
-
-	if (image) ui_edit_widget_set_path_key(wd, "image", dir, image);
 
 	ui_edit_write_section(f, "font", wd->key);
 
-	ui_edit_write_key_char(f, "image", image);
-	ui_edit_write_key_bool(f, "extended", font->extended);
+	if (font->overlay)
+		{
+		gchar *image;
 
-	g_free(image);
+		image = ui_edit_copy_unique_file(ui_widget_get_data(wd, "image"),
+						 dir, font->overlay, "font_", wd->key);
+		if (image) ui_edit_widget_set_path_key(wd, "image", dir, image);
+
+		ui_edit_write_key_char(f, "image", image);
+		ui_edit_write_key_bool(f, "extended", font->extended);
+
+		g_free(image);
+		}
+	else
+		{
+		ui_edit_write_key_char(f, "description", font->font_description);
+		}
 }
 
 static FontListData *font_edit_list_find(GList *list, const gchar *image)
@@ -135,9 +146,14 @@ static gpointer font_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 
 		fd->extended_button = ui_edit_toggle_new(vbox, _("Extended"));
 		gtk_widget_set_sensitive(fd->extended_button, FALSE);
+
+		fd->font_entry = ui_edit_entry_new(vbox, _("Font:"));
+		ui_edit_frame_sensitive(fd->font_entry, FALSE, TRUE);
+
 		}
 
 	ui_edit_toggle_set(fd->extended_button, font->extended);
+	ui_edit_entry_set(fd->font_entry, font->font_description);
 
 	return fd;
 }
@@ -177,11 +193,19 @@ typedef struct _TextDetail TextDetail;
 struct _TextDetail
 {
 	TextData *text;
-	GtkWidget *spin_length;
+	GtkWidget *spin_width;
 	GtkWidget *extended_button;
 	GtkWidget *sizeable_button;
+	GtkWidget *spin_rotation;
 	GtkWidget *font_key_entry;
 
+	GtkWidget *font_entry;
+
+	GtkWidget *red_spin;
+	GtkWidget *green_spin;
+	GtkWidget *blue_spin;
+	GtkWidget *alpha_spin;
+
 	WidgetData *wd;
 	UIData *ui;
 };
@@ -198,7 +222,15 @@ struct _TextPage
 
 	GtkWidget *extended_button;
 	GtkWidget *sizeable_button;
-	GtkWidget *length_spin;
+	GtkWidget *spin_rotation;
+	GtkWidget *spin_width;
+
+	GtkWidget *font_entry;
+
+	GtkWidget *red_spin;
+	GtkWidget *green_spin;
+	GtkWidget *blue_spin;
+	GtkWidget *alpha_spin;
 
 	GtkWidget *clist;
 	GtkWidget *pixmap;
@@ -218,37 +250,46 @@ static GdkPixbuf *text_get_pixbuf(gpointer data)
 static void text_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar *dir)
 {
 	TextData *text = wd->widget;
-	gchar *image = NULL;
 	const gchar *file;
 	const gchar *font_id;
 
 	file = ui_widget_get_data(wd, "image");
 	font_id = ui_widget_get_data(wd, "font_id");
-	if (file || (!file && !font_id))
-		{
-		image = ui_edit_copy_unique_file(file, dir, text->font->overlay, "text_", wd->key);
-		}
-
-	if (image) ui_edit_widget_set_path_key(wd, "image", dir, image);
 
 	ui_edit_write_section(f, "text", wd->key);
 
-	if (image)
+	if (!font_id && text->font->overlay)
 		{
+		gchar *image;
+
+		image = ui_edit_copy_unique_file(file, dir, text->font->overlay, "text_", wd->key);
+		ui_edit_widget_set_path_key(wd, "image", dir, image);
+
 		ui_edit_write_key_char(f, "image", image);
 		ui_edit_write_key_bool(f, "extended", text->font->extended);
+
+		g_free(image);
 		}
-	else
+	else if (font_id)
 		{
 		ui_edit_write_key_char(f, "font", font_id);
 		}
+	else
+		{
+		ui_edit_write_key_char(f, "description", text->font->font_description);
+		ui_edit_write_key_int(f, "red", (gint)text->r);
+		ui_edit_write_key_int(f, "green", (gint)text->g);
+		ui_edit_write_key_int(f, "blue", (gint)text->b);
+		ui_edit_write_key_int(f, "alpha", (gint)text->a);
+		}
+
 	ui_edit_write_key_int(f, "x", text->x);
 	ui_edit_write_key_int(f, "y", text->y);
-	ui_edit_write_key_int(f, "length", text->length);
+	ui_edit_write_key_int(f, "width", font_rotation_vertical(text->rotation) ? text->height : text->width);
 
 	ui_edit_write_key_bool(f, "sizeable", text->sizeable);
 
-	g_free(image);
+	ui_edit_write_key_int(f, "rotation", text->rotation);
 }
 
 static gpointer text_edit_read(UIData *ui, WidgetData *wd, GList *list)
@@ -279,40 +320,133 @@ static void text_edit_props_sizeable_cb(GtkWidget *widget, gpointer data)
 	td->text->sizeable = ui_edit_toggle_get(td->sizeable_button);
 }
 
-static void text_edit_props_length_cb(GtkAdjustment *adjustment, gpointer data)
+static void text_edit_props_rotation_cb(GtkAdjustment *adjustment, gpointer data)
 {
 	TextDetail *td = data;
-	gint new_length;
-	gint old_w, w;
+	TextData *text;
+	gint new_r;
+	gint cw, ch;
 
-	new_length = ui_edit_spin_get(td->spin_length);
+	text = td->text;
+	new_r = ui_edit_spin_get(td->spin_rotation);
 
-	if (new_length * td->text->font->char_width > td->ui->skin->width)
+	if (font_rotation_vertical(new_r) != font_rotation_vertical(text->rotation))
 		{
-		new_length = td->ui->skin->width / td->text->font->char_width;
-		ui_edit_spin_set_blocking(td->spin_length, new_length, td);
+		gint old_w, old_h;
+		gint t;
+
+		old_w = text->width;
+		old_h = text->height;
+
+		ui_edit_widget_draw_highlight(td->ui, td->wd, FALSE);
+
+		if (font_rotation_vertical(new_r))
+			{
+			if (text->y + text->width > td->ui->skin->height)
+				{
+				text->width = td->ui->skin->height - text->y;
+				ui_edit_spin_set_blocking(td->spin_width, text->width, td);
+				}
+			}
+		else
+			{
+			if (text->x + text->height > td->ui->skin->width)
+				{
+				text->height = td->ui->skin->width - text->x;
+				ui_edit_spin_set_blocking(td->spin_width, text->height, td);
+				}
+			}
+
+		t = text->width;
+		text->width = text->height;
+		text->height = t;
+		gdk_pixbuf_unref(text->pixbuf);
+		text->pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, text->width, text->height);
+
+		cw = MAX(0, old_w - text->width);
+		ch = MAX(0, old_h - text->height);
+		}
+	else
+		{
+		cw = ch = 0;
+		}
+	text->rotation = new_r;
+
+	ui_edit_widget_resync(td->ui, td->wd, TRUE, cw, ch);
+}
+
+static void text_edit_props_width_cb(GtkAdjustment *adjustment, gpointer data)
+{
+	TextDetail *td = data;
+	gint new_w;
+	gint old_w;
+
+	new_w = ui_edit_spin_get(td->spin_width);
+
+	if (font_rotation_vertical(td->text->rotation))
+		{
+		if (new_w > td->ui->skin->height)
+			{
+			new_w = td->ui->skin->height;
+			ui_edit_spin_set_blocking(td->spin_width, new_w, td);
+			}
+
+		if (new_w == td->text->height) return;
+
+		old_w = td->text->height;
+
+		if (new_w > td->text->height &&
+		    td->text->y + new_w > td->ui->skin->height)
+			{
+			ui_widget_set_coord(td->ui, td->wd, td->text->x, td->ui->skin->height - new_w, TRUE);
+			}
+
+		if (old_w > new_w) ui_edit_widget_draw_highlight(td->ui, td->wd, FALSE);
+		
+		td->text->height = new_w;
+		}
+	else
+		{
+		if (new_w > td->ui->skin->width)
+			{
+			new_w = td->ui->skin->width;
+			ui_edit_spin_set_blocking(td->spin_width, new_w, td);
+			}
+
+		if (new_w == td->text->width) return;
+
+		old_w = td->text->width;
+
+		if (new_w > td->text->width &&
+		    td->text->x + new_w > td->ui->skin->width)
+			{
+			ui_widget_set_coord(td->ui, td->wd, td->ui->skin->width - new_w, td->text->y, TRUE);
+			}
+
+		if (old_w > new_w) ui_edit_widget_draw_highlight(td->ui, td->wd, FALSE);
+
+		td->text->width = new_w;
 		}
 
-	if (new_length == td->text->length) return;
-
-	old_w = td->text->width;
-	w = td->text->font->char_width * new_length;
-
-	if (new_length > td->text->length &&
-	    td->text->x + w > td->ui->skin->width)
-		{
-		ui_widget_set_coord(td->ui, td->wd, td->ui->skin->width - w, td->text->y, TRUE);
-		}
-
-	if (old_w > w) ui_edit_widget_draw_highlight(td->ui, td->wd, FALSE);
-
-	td->text->length = new_length;
-	td->text->width = w;
-	td->text->size_width = w;
 	gdk_pixbuf_unref(td->text->pixbuf);
-	td->text->pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, w, td->text->height);
+	td->text->pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, new_w, td->text->height);
 
-	ui_edit_widget_resync(td->ui, td->wd, TRUE, old_w > w ? old_w - w : 0, 0);
+	ui_edit_widget_resync(td->ui, td->wd, TRUE, old_w > new_w ? old_w - new_w : 0, 0);
+}
+
+static void text_edit_props_color_cb(GtkAdjustment *adjustment, gpointer data)
+{
+	TextDetail *td = data;
+	TextData *text;
+
+	text = td->text;
+
+	text->r = ui_edit_spin_get(td->red_spin);
+	text->g = ui_edit_spin_get(td->green_spin);
+	text->b = ui_edit_spin_get(td->blue_spin);
+	text->a = ui_edit_spin_get(td->alpha_spin);
+
+	ui_widget_draw(td->ui, td->wd, TRUE, TRUE);
 }
 
 static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpointer detail)
@@ -334,9 +468,34 @@ static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 		gtk_signal_connect(GTK_OBJECT(td->sizeable_button), "clicked",
 				   GTK_SIGNAL_FUNC(text_edit_props_sizeable_cb), td);
 
-		td->spin_length = ui_edit_spin_new(vbox, _("length:"), 1, 200, &adj);
+		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
+		td->spin_width = ui_edit_spin_new(hbox, _("Width:"), 1, 2000, &adj);
 		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_length_cb), td);
+				   GTK_SIGNAL_FUNC(text_edit_props_width_cb), td);
+		td->spin_rotation = ui_edit_spin_new(hbox, _("Rotation:"), 0, 270, &adj);
+		GTK_ADJUSTMENT(adj)->step_increment = 90.0;
+		gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(td->spin_rotation), TRUE);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(text_edit_props_rotation_cb), td);
+
+		td->font_entry = ui_edit_entry_new(vbox, _("Font:"));
+		ui_edit_frame_sensitive(td->font_entry, FALSE, TRUE);
+
+		hbox = ui_edit_frame_new(vbox, TRUE, _("Color"));
+
+		td->red_spin = ui_edit_spin_new(hbox, _("Red:"), 0, 255, &adj);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		td->green_spin = ui_edit_spin_new(hbox, _("Green:"), 0, 255, &adj);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		td->blue_spin = ui_edit_spin_new(hbox, _("Blue:"), 0, 255, &adj);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+
+		td->alpha_spin = ui_edit_spin_new(vbox, _("Alpha:"), 0, 255, &adj);
+		gtk_signal_connect(adj, "value_changed",
+				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
@@ -351,7 +510,19 @@ static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 	ui_edit_toggle_set(td->extended_button, text->font->extended);
 	ui_edit_toggle_set_blocking(td->sizeable_button, text->sizeable, td);
 
-	ui_edit_spin_set_blocking(td->spin_length, text->length, td);
+	ui_edit_spin_set_blocking(td->spin_width, font_rotation_vertical(text->rotation) ? text->height : text->width, td);
+	ui_edit_spin_set_blocking(td->spin_rotation, text->rotation, td);
+
+	ui_edit_entry_set(td->font_entry, text->font->font_description);
+
+	ui_edit_spin_set_blocking(td->red_spin, text->r, td);
+	ui_edit_spin_set_blocking(td->green_spin, text->g, td);
+	ui_edit_spin_set_blocking(td->blue_spin, text->b, td);
+	ui_edit_spin_set_blocking(td->alpha_spin, text->a, td);
+
+	ui_edit_frame_sensitive(td->red_spin, (text->font->overlay == NULL), FALSE);
+	ui_edit_frame_sensitive(td->alpha_spin, (text->font->overlay == NULL), TRUE);
+
 	ui_edit_entry_set(td->font_key_entry, ui_widget_get_data(wd, "font_id"));
 
 	return td;
@@ -363,21 +534,34 @@ static void text_edit_page_font_add_cb(GtkWidget *widget, gpointer data)
 	FontData *font;
 	const gchar *key;
 	const gchar *text_id;
+	const gchar *font_desc;
 	const gchar *image;
 	gint extended;
 
 	key = ui_edit_entry_get(pd->font_key_entry);
 	text_id = ui_edit_entry_get(pd->text_id_entry);
+	font_desc = ui_edit_entry_get(pd->font_entry);;
 	image = ui_edit_entry_get(pd->image_entry);
 	extended = ui_edit_toggle_get(pd->extended_button);
 
-	if (!key || !image || !isfile(image))
+	if (!key || (!font_desc && (!image || !isfile(image)) ) )
 		{
-		warning_dialog(_("Font error"), _("Font must contain a key and valid image."));
+		warning_dialog(_("Font error"), _("Font must contain a key and valid font description or image."));
 		return;
 		}
 
-	font = font_new_from_file(image, extended);
+	if (font_desc)
+		{
+		font = font_new_from_x(font_desc);
+		if (!font)
+			{
+			warning_dialog(_("Invalid font"), _("Specified font not found, text not created"));
+			}
+		}
+	else
+		{
+		font = font_new_from_file(image, extended);
+		}
 	
 	if (font)
 		{
@@ -398,17 +582,21 @@ static void text_edit_page_add_cb(GtkWidget *widget, gpointer data)
 	const gchar *key;
 	const gchar *text_id;
 	const gchar *font_id;
+	const gchar *font_desc;
 	const gchar *image;
 
 	key = ui_edit_entry_get(pd->key_entry);
 	text_id = ui_edit_entry_get(pd->text_id_entry);
 	font_id = ui_edit_entry_get(pd->font_id_entry);
+	font_desc = ui_edit_entry_get(pd->font_entry);
 	image = ui_edit_entry_get(pd->image_entry);
 
 	if (!key ||
-	    ( (!font_id || !ui_widget_exists(pd->ed->ui, font_id, font_type_id())) && (font_id || !image || !isfile(image)) ) )
+	    (!font_id && !image && !font_desc) ||
+	    (font_id && !ui_widget_exists(pd->ed->ui, font_id, font_type_id())) ||
+	    (!font_id && !font_desc && image && !isfile(image)))
 		{
-		warning_dialog(_("Text error"), _("Text must contain a key, and valid image or font key."));
+		warning_dialog(_("Text error"), _("Text must contain a key, and valid image, font description, or font key."));
 		return;
 		}
 
@@ -418,22 +606,48 @@ static void text_edit_page_add_cb(GtkWidget *widget, gpointer data)
 		WidgetData *wd;
 
 		wd = skin_widget_get_by_key(pd->ed->ui->skin, font_id, font_type_id());
-		font = wd->widget;
-		text = text_new(font, 0, 0,
-				ui_edit_spin_get(pd->length_spin),
-				ui_edit_toggle_get(pd->sizeable_button));
+		if (wd)
+			{
+			font = wd->widget;
+			text = text_new(font, 0, 0,
+					ui_edit_spin_get(pd->spin_width),
+					ui_edit_toggle_get(pd->sizeable_button),
+					ui_edit_spin_get(pd->spin_rotation));
+			}
+		else
+			{
+			text = NULL;
+			}
 		image = NULL;
 		}
+	else if (font_desc)
+		{
+		text = text_new_from_x(font_desc, 0, 0,
+				       ui_edit_spin_get(pd->spin_width),
+				       ui_edit_toggle_get(pd->sizeable_button),
+				       ui_edit_spin_get(pd->spin_rotation));
+		if (!text)
+			{
+			warning_dialog(_("Invalid font"), _("Specified font not found, text not created"));
+			}
+		}
 	else
 		{
 		text = text_new_from_file(image, 0, 0,
-					  ui_edit_spin_get(pd->length_spin),
+					  ui_edit_spin_get(pd->spin_width),
 					  ui_edit_toggle_get(pd->sizeable_button),
+					  ui_edit_spin_get(pd->spin_rotation),
 					  ui_edit_toggle_get(pd->extended_button));
 		}
 	if (text)
 		{
 		WidgetData *wd;
+
+		text_set_color(text, ui_edit_spin_get(pd->red_spin),
+			       ui_edit_spin_get(pd->green_spin),
+			       ui_edit_spin_get(pd->blue_spin),
+			       ui_edit_spin_get(pd->alpha_spin));
+
 		wd = text_register(pd->ed->ui->skin, text, key, text_id);
 		ui_widget_set_data(wd, "font_id", font_id);
 		ui_edit_widget_add_finish(pd->ed, wd, image, ui_edit_entry_get(pd->data_entry));
@@ -446,7 +660,9 @@ static void text_edit_page_sync(TextPage *pd, FontListData *fd)
 {
 	if (!fd) return;
 
+	ui_edit_entry_set(pd->font_entry, fd->description);
 	ui_edit_entry_set(pd->image_entry, fd->image);
+
 	ui_edit_toggle_set(pd->extended_button, fd->extended);
 }
 
@@ -462,11 +678,13 @@ static void text_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEve
 static void text_edit_page_font_cb(GtkWidget *entry, gpointer data)
 {
 	TextPage *pd = data;
-	gint state;
+	gint a, b;
 
-	state = (strlen(gtk_entry_get_text(GTK_ENTRY(pd->font_id_entry))) == 0);
+	a = (strlen(gtk_entry_get_text(GTK_ENTRY(pd->font_id_entry))) == 0);
+	b = (strlen(gtk_entry_get_text(GTK_ENTRY(pd->font_entry))) == 0);
 
-	ui_edit_frame_sensitive(pd->image_entry, state, TRUE);
+	ui_edit_frame_sensitive(pd->font_entry, a, TRUE);
+	ui_edit_frame_sensitive(pd->image_entry, (a && b), TRUE);
 }
 
 static void text_edit_page_destroy_cb(GtkWidget *widget, gpointer data)
@@ -479,10 +697,12 @@ static void text_edit_page_destroy_cb(GtkWidget *widget, gpointer data)
 static GtkWidget *text_edit_page_new(EditData *ed)
 {
 	GtkWidget *hbox;
+	GtkWidget *hbox2;
 	GtkWidget *vbox;
 	GtkWidget *frame;
 	GtkWidget *button;
 	GtkWidget *sep;
+	GtkObject *adj;
 	TextPage *pd;
 	gchar *titles[] = { _("Image"), _("Key"), _("Extended"), NULL };
 
@@ -505,15 +725,34 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 
 	pd->extended_button = ui_edit_toggle_new(vbox, _("Extended"));
 	pd->sizeable_button = ui_edit_toggle_new(vbox, _("Dynamic size"));
-	pd->length_spin = ui_edit_spin_new(vbox, _("Length:"), 1, 200, NULL);
+
+	hbox2 = ui_edit_frame_new(vbox, FALSE, NULL);
+	
+	pd->spin_width = ui_edit_spin_new(hbox2, _("Width:"), 1, 2000, NULL);
+
+	pd->spin_rotation = ui_edit_spin_new(hbox2, _("Rotation:"), 0, 270, &adj);
+	GTK_ADJUSTMENT(adj)->step_increment = 90.0;
+	gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(pd->spin_rotation), TRUE);
 
 	pd->font_id_entry = ui_edit_entry_new(vbox, _("Font key:"));
 	gtk_signal_connect(GTK_OBJECT(pd->font_id_entry), "changed",
 			   GTK_SIGNAL_FUNC(text_edit_page_font_cb), pd);
+
+	pd->font_entry = ui_edit_font_entry_new(vbox, _("Font:"));
+	gtk_signal_connect(GTK_OBJECT(pd->font_entry), "changed",
+			   GTK_SIGNAL_FUNC(text_edit_page_font_cb), pd);
+
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_text_image");
 	pd->pixmap = ui_edit_pixmap_new(vbox);
 	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
 
+	frame = ui_edit_frame_new(vbox, TRUE, _("Color"));
+	pd->red_spin = ui_edit_spin_new(frame, _("Red:"), 0, 255, NULL);
+	pd->green_spin = ui_edit_spin_new(frame, _("Green:"), 0, 255, NULL);
+	pd->blue_spin = ui_edit_spin_new(frame, _("Blue:"), 0, 255, NULL);
+
+	pd->alpha_spin = ui_edit_spin_new(vbox, _("Alpha:"), 0, 255, NULL);
+
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
@@ -542,6 +781,12 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 	/* hacky, but it works */
 	ui_edit_widget_id_list_set_page(ed->widget_id_list, font_type_id(), hbox);
 
+	ui_edit_spin_set(pd->red_spin, 0);
+	ui_edit_spin_set(pd->green_spin, 0);
+	ui_edit_spin_set(pd->blue_spin, 0);
+	ui_edit_spin_set(pd->alpha_spin, 255);
+	gtk_entry_set_text(GTK_ENTRY(pd->font_entry), SLIK_DEFAULT_X_FONT);
+
 	return hbox;
 }
 
@@ -575,4 +820,3 @@ void text_type_init_edit(WidgetObjectData *od)
 	od->func_edit_page_new = text_edit_page_new;
 	od->func_edit_page_add = text_edit_page_add;
 }
-
