@@ -19,7 +19,7 @@
  *-------------------------------------
  */
 
-#define SLIK_VERSION "0.10.0"
+#define SLIK_VERSION "0.13.0"
 
 #define SKIN_SIZE_MIN 4
 #define SKIN_SIZE_MAX 2000
@@ -178,6 +178,15 @@ struct _SkinData
 	gchar *background_filename;		/* used by editor */
 	gchar *background_mask_filename;	/* " */
 	gchar *focus_filename;
+
+	/* used by widgets that need extra offscreen scratch areas to work in */
+	GdkPixbuf *scratch_pixbuf;
+	GdkPixmap *scratch_pixmap;
+
+	/* delayed idle resize */
+	gint resize_idle_id;
+	gint resize_idle_width;
+	gint resize_idle_height;
 };
 
 
@@ -196,6 +205,7 @@ struct _UIData
 
 	gint decorations;	/* show decorations */
 	gint allow_move;	/* move by dragging mouse */
+	gint focus_enable;	/* force keyboard focus on, usually only for menus */
 
 	/* called for click on a button greater than 2 (3, 4, 5, etc.) */
 	void (*click_func)(UIData *ui, gint button, guint32 time, gpointer data);
@@ -300,6 +310,28 @@ struct _EditData
 	gint help_follow;
 
 	gchar *help_path;
+
+	/* comments */
+	GtkWidget *comment_window;
+	GtkWidget *comment_title_entry;
+	GtkWidget *comment_version_entry;
+	GtkWidget *comment_author_entry;
+	GtkWidget *comment_email_entry;
+	GtkWidget *comment_url_entry;
+	GtkWidget *comment_license_entry;
+	GtkWidget *comment_misc_entry;
+	GtkWidget *comment_build_spin;
+	GtkWidget *comment_stamp_label;
+
+	gchar *comment_title;
+	gchar *comment_version;
+	gchar *comment_author;
+	gchar *comment_email;
+	gchar *comment_url;
+	gchar *comment_license;
+	gchar *comment_misc;
+	gint comment_build;
+	gchar *comment_stamp;
 };
 
 
