@@ -44,6 +44,21 @@ void util_size(gint *n)
 		}
 }
 
+void util_color(gint *r, gint *g, gint *b, gint *a)
+{
+	if (slik_colorshift_on)
+		{
+		guint8 a = slik_colorshift_a;
+		if (r) *r = (*r * (256 - a) + slik_colorshift_r * a) >> 8;
+		if (g) *g = (*g * (256 - a) + slik_colorshift_g * a) >> 8;
+		if (b) *b = (*b * (256 - a) + slik_colorshift_b * a) >> 8;
+		}
+	if ((a) && slik_transparency_force)
+		{
+		*a = (*a * slik_transparency_force_a) >> 8;
+		}
+}
+
 GdkPixbuf *util_size_pixbuf(GdkPixbuf *pb, gint apply_adjustments)
 {
 	if (slik_scale && slik_scale_value > 0.1)
