@@ -26,6 +26,10 @@
 
 #include <gdk/gdkkeysyms.h> /* for key values */
 
+#ifdef HAVE_XF86_KEYSYMS
+  #include <X11/XF86keysym.h>
+#endif
+
 static gint key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
 	static gint last_key = 0;
@@ -193,6 +197,44 @@ static gint key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 			case '~': case '`':
 				btn_edit_skin_pressed(ui);
 				break;
+#ifdef HAVE_XF86_KEYSYMS
+			case XF86XK_AudioLowerVolume:
+				btn_volume_down_pressed();
+				btn_volume_released();
+				break;
+			case XF86XK_AudioMute:
+				/* FIXME: gqmpeg has no mute facility */
+				btn_mixer_pressed();
+				break;
+			case XF86XK_AudioRaiseVolume:
+				btn_volume_up_pressed();
+				btn_volume_released();
+				break;
+			case XF86XK_AudioPlay:
+				btn_play_pressed();
+				break;
+			case XF86XK_AudioStop:
+				btn_stop_pressed();
+				break;
+			case XF86XK_AudioPrev:
+				btn_prev_down();
+				btn_prev_pressed();
+				break;
+			case XF86XK_AudioNext:
+				btn_next_down();
+				btn_next_pressed();
+				break;
+			case XF86XK_AudioPause:
+				btn_pause_pressed();
+				break;
+			case XF86XK_AudioMedia:
+			case XF86XK_Eject:
+				playlist_window_toggle();
+				break;
+			case XF86XK_OpenURL:
+				btn_load_file_pressed();
+				break;
+#endif
 			default:
 				ret = FALSE;
 				break;
@@ -263,10 +305,20 @@ static void main_window_mouse_cb(UIData *ui, gint button, guint32 time, gpointer
 
 }
 
+static gint subwindow_delete_cb(GtkWidget *widget, GdkEventAny *event, gpointer data)
+{
+	UIData *ui = data;
+
+	ui_close(ui);
+	return TRUE;
+}
+
 static void main_window_new_subwindow_cb(UIData *child, const gchar *key, gpointer data)
 {
 	const gchar *title;
 
+	gtk_signal_connect(GTK_OBJECT(child->window), "delete_event",
+			   GTK_SIGNAL_FUNC(subwindow_delete_cb), child);
 	gtk_signal_connect(GTK_OBJECT(child->display), "key_press_event",
 			   GTK_SIGNAL_FUNC(key_pressed), child);
 
